Class: Google::Cloud::Bigtable::V2::AllReadStats

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/bigtable/v2/request_stats.rb

Overview

AllReadStats captures all known information about a read.

Instance Attribute Summary collapse

Instance Attribute Details

#read_iterator_stats::Google::Cloud::Bigtable::V2::ReadIteratorStats

Returns Iteration stats describe how efficient the read is, e.g. comparing rows seen vs. rows returned or cells seen vs cells returned can provide an indication of read efficiency (the higher the ratio of seen to retuned the better).

Returns:

  • (::Google::Cloud::Bigtable::V2::ReadIteratorStats)

    Iteration stats describe how efficient the read is, e.g. comparing rows seen vs. rows returned or cells seen vs cells returned can provide an indication of read efficiency (the higher the ratio of seen to retuned the better).



96
97
98
99
# File 'proto_docs/google/bigtable/v2/request_stats.rb', line 96

class AllReadStats
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_latency_stats::Google::Cloud::Bigtable::V2::RequestLatencyStats

Returns Request latency stats describe the time taken to complete a request, from the server side.

Returns:



96
97
98
99
# File 'proto_docs/google/bigtable/v2/request_stats.rb', line 96

class AllReadStats
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end