Class: Google::Cloud::Bigtable::V2::AuthorizedViewResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::AuthorizedViewResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/session.rb
Overview
A response wrapper for operations on an authorized view. Internal usage only.
Instance Attribute Summary collapse
-
#mutate_row ⇒ ::Google::Cloud::Bigtable::V2::SessionMutateRowResponse
Note: The following fields are mutually exclusive:
mutate_row,read_row. -
#read_row ⇒ ::Google::Cloud::Bigtable::V2::SessionReadRowResponse
Note: The following fields are mutually exclusive:
read_row,mutate_row.
Instance Attribute Details
#mutate_row ⇒ ::Google::Cloud::Bigtable::V2::SessionMutateRowResponse
Returns Note: The following fields are mutually exclusive: mutate_row, read_row. If a field in that set is populated, all other fields in the set will automatically be cleared.
655 656 657 658 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 655 class AuthorizedViewResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#read_row ⇒ ::Google::Cloud::Bigtable::V2::SessionReadRowResponse
Returns Note: The following fields are mutually exclusive: read_row, mutate_row. If a field in that set is populated, all other fields in the set will automatically be cleared.
655 656 657 658 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 655 class AuthorizedViewResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |