Class: Google::Cloud::Bigtable::V2::Bigtable::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::Bigtable::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/bigtable/v2/bigtable/client.rb
Overview
Client for the Bigtable service.
Service for reading from and writing to existing Bigtable tables.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the Bigtable Client class.
Instance Method Summary collapse
-
#check_and_mutate_row(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Bigtable::V2::CheckAndMutateRowResponse
Mutates a row atomically based on the output of a predicate Reader filter.
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the Bigtable Client instance.
-
#execute_query(request, options = nil) {|response, operation| ... } ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ExecuteQueryResponse>
Executes a SQL query against a particular Bigtable instance.
-
#generate_initial_change_stream_partitions(request, options = nil) {|response, operation| ... } ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::GenerateInitialChangeStreamPartitionsResponse>
NOTE: This API is intended to be used by Apache Beam BigtableIO.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new Bigtable client object.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#mutate_row(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Bigtable::V2::MutateRowResponse
Mutates a row atomically.
-
#mutate_rows(request, options = nil) {|response, operation| ... } ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::MutateRowsResponse>
Mutates multiple rows in a batch.
-
#ping_and_warm(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Bigtable::V2::PingAndWarmResponse
Warm up associated instance metadata for this connection.
-
#prepare_query(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Bigtable::V2::PrepareQueryResponse
Prepares a GoogleSQL query for execution on a particular Bigtable instance.
-
#read_change_stream(request, options = nil) {|response, operation| ... } ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ReadChangeStreamResponse>
NOTE: This API is intended to be used by Apache Beam BigtableIO.
-
#read_modify_write_row(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Bigtable::V2::ReadModifyWriteRowResponse
Modifies a row atomically on the server.
-
#read_rows(request, options = nil) {|response, operation| ... } ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ReadRowsResponse>
Streams back the contents of all requested rows in key order, optionally applying the same Reader filter to each.
-
#sample_row_keys(request, options = nil) {|response, operation| ... } ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::SampleRowKeysResponse>
Returns a sample of row keys in the table.
-
#universe_domain ⇒ String
The effective universe domain.
Methods included from Paths
#authorized_view_path, #instance_path, #materialized_view_path, #table_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new Bigtable client object.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 148 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/bigtable/v2/bigtable_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @bigtable_stub = ::Gapic::ServiceStub.new( ::Google::Cloud::Bigtable::V2::Bigtable::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool, logger: @config.logger ) @bigtable_stub.stub_logger&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the Bigtable Client class.
See Configuration for a description of the configuration fields.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 62 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Bigtable", "V2"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.read_rows.timeout = 43_200.0 default_config.rpcs.sample_row_keys.timeout = 60.0 default_config.rpcs.mutate_row.timeout = 60.0 default_config.rpcs.mutate_row.retry_policy = { initial_delay: 0.01, max_delay: 60.0, multiplier: 2, retry_codes: [14, 4] } default_config.rpcs.mutate_rows.timeout = 600.0 default_config.rpcs.check_and_mutate_row.timeout = 20.0 default_config.rpcs.read_modify_write_row.timeout = 20.0 default_config.rpcs.generate_initial_change_stream_partitions.timeout = 60.0 default_config.rpcs.read_change_stream.timeout = 43_200.0 default_config.rpcs.execute_query.timeout = 43_200.0 default_config.rpcs.execute_query.retry_policy = { initial_delay: 0.01, max_delay: 60.0, multiplier: 2, retry_codes: [14, 4] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#check_and_mutate_row(request, options = nil) ⇒ ::Google::Cloud::Bigtable::V2::CheckAndMutateRowResponse #check_and_mutate_row(table_name: nil, authorized_view_name: nil, app_profile_id: nil, row_key: nil, predicate_filter: nil, true_mutations: nil, false_mutations: nil) ⇒ ::Google::Cloud::Bigtable::V2::CheckAndMutateRowResponse
Mutates a row atomically based on the output of a predicate Reader filter.
773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 773 def check_and_mutate_row request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::CheckAndMutateRowRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.check_and_mutate_row..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::V2::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.table_name && %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/?$}.match?(request.table_name) header_params["table_name"] = request.table_name end if request.app_profile_id && !request.app_profile_id.empty? header_params["app_profile_id"] = request.app_profile_id end if request. && %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/authorizedViews/[^/]+/?$}.match?(request.) header_params["authorized_view_name"] = request. end request_params_header = URI.encode_www_form header_params [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.check_and_mutate_row.timeout, metadata: , retry_policy: @config.rpcs.check_and_mutate_row.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @bigtable_stub.call_rpc :check_and_mutate_row, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#configure {|config| ... } ⇒ Client::Configuration
Configure the Bigtable Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
118 119 120 121 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 118 def configure yield @config if block_given? @config end |
#execute_query(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ExecuteQueryResponse> #execute_query(instance_name: nil, app_profile_id: nil, query: nil, prepared_query: nil, proto_format: nil, resume_token: nil, params: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ExecuteQueryResponse>
Executes a SQL query against a particular Bigtable instance.
1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 1474 def execute_query request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::ExecuteQueryRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.execute_query..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::V2::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.instance_name && %r{^projects/[^/]+/instances/[^/]+/?$}.match?(request.instance_name) header_params["name"] = request.instance_name end if request.app_profile_id && !request.app_profile_id.empty? header_params["app_profile_id"] = request.app_profile_id end request_params_header = URI.encode_www_form header_params [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.execute_query.timeout, metadata: , retry_policy: @config.rpcs.execute_query.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @bigtable_stub.call_rpc :execute_query, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#generate_initial_change_stream_partitions(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::GenerateInitialChangeStreamPartitionsResponse> #generate_initial_change_stream_partitions(table_name: nil, app_profile_id: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::GenerateInitialChangeStreamPartitionsResponse>
NOTE: This API is intended to be used by Apache Beam BigtableIO.
Returns the current list of partitions that make up the table's
change stream. The union of partitions will cover the entire keyspace.
Partitions can be read with ReadChangeStream.
1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 1091 def generate_initial_change_stream_partitions request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::GenerateInitialChangeStreamPartitionsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.generate_initial_change_stream_partitions..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::V2::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.table_name header_params["table_name"] = request.table_name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.generate_initial_change_stream_partitions.timeout, metadata: , retry_policy: @config.rpcs.generate_initial_change_stream_partitions.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @bigtable_stub.call_rpc :generate_initial_change_stream_partitions, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
204 205 206 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 204 def logger @bigtable_stub.logger end |
#mutate_row(request, options = nil) ⇒ ::Google::Cloud::Bigtable::V2::MutateRowResponse #mutate_row(table_name: nil, authorized_view_name: nil, app_profile_id: nil, row_key: nil, mutations: nil) ⇒ ::Google::Cloud::Bigtable::V2::MutateRowResponse
Mutates a row atomically. Cells already present in the row are left
unchanged unless explicitly changed by mutation.
530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 530 def mutate_row request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::MutateRowRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.mutate_row..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::V2::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.table_name && %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/?$}.match?(request.table_name) header_params["table_name"] = request.table_name end if request.app_profile_id && !request.app_profile_id.empty? header_params["app_profile_id"] = request.app_profile_id end if request. && %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/authorizedViews/[^/]+/?$}.match?(request.) header_params["authorized_view_name"] = request. end request_params_header = URI.encode_www_form header_params [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.mutate_row.timeout, metadata: , retry_policy: @config.rpcs.mutate_row.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @bigtable_stub.call_rpc :mutate_row, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#mutate_rows(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::MutateRowsResponse> #mutate_rows(table_name: nil, authorized_view_name: nil, app_profile_id: nil, entries: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::MutateRowsResponse>
Mutates multiple rows in a batch. Each individual row is mutated atomically as in MutateRow, but the entire batch is not executed atomically.
647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 647 def mutate_rows request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::MutateRowsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.mutate_rows..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::V2::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.table_name && %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/?$}.match?(request.table_name) header_params["table_name"] = request.table_name end if request.app_profile_id && !request.app_profile_id.empty? header_params["app_profile_id"] = request.app_profile_id end if request. && %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/authorizedViews/[^/]+/?$}.match?(request.) header_params["authorized_view_name"] = request. end request_params_header = URI.encode_www_form header_params [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.mutate_rows.timeout, metadata: , retry_policy: @config.rpcs.mutate_rows.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @bigtable_stub.call_rpc :mutate_rows, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#ping_and_warm(request, options = nil) ⇒ ::Google::Cloud::Bigtable::V2::PingAndWarmResponse #ping_and_warm(name: nil, app_profile_id: nil) ⇒ ::Google::Cloud::Bigtable::V2::PingAndWarmResponse
Warm up associated instance metadata for this connection. This call is not required but may be useful for connection keep-alive.
872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 872 def ping_and_warm request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::PingAndWarmRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.ping_and_warm..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::V2::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name && %r{^projects/[^/]+/instances/[^/]+/?$}.match?(request.name) header_params["name"] = request.name end if request.app_profile_id && !request.app_profile_id.empty? header_params["app_profile_id"] = request.app_profile_id end request_params_header = URI.encode_www_form header_params [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.ping_and_warm.timeout, metadata: , retry_policy: @config.rpcs.ping_and_warm.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @bigtable_stub.call_rpc :ping_and_warm, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#prepare_query(request, options = nil) ⇒ ::Google::Cloud::Bigtable::V2::PrepareQueryResponse #prepare_query(instance_name: nil, app_profile_id: nil, query: nil, proto_format: nil, param_types: nil) ⇒ ::Google::Cloud::Bigtable::V2::PrepareQueryResponse
Prepares a GoogleSQL query for execution on a particular Bigtable instance.
1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 1327 def prepare_query request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::PrepareQueryRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.prepare_query..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::V2::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.instance_name && %r{^projects/[^/]+/instances/[^/]+/?$}.match?(request.instance_name) header_params["name"] = request.instance_name end if request.app_profile_id && !request.app_profile_id.empty? header_params["app_profile_id"] = request.app_profile_id end request_params_header = URI.encode_www_form header_params [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.prepare_query.timeout, metadata: , retry_policy: @config.rpcs.prepare_query.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @bigtable_stub.call_rpc :prepare_query, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#read_change_stream(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ReadChangeStreamResponse> #read_change_stream(table_name: nil, app_profile_id: nil, partition: nil, start_time: nil, continuation_tokens: nil, end_time: nil, heartbeat_duration: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ReadChangeStreamResponse>
NOTE: This API is intended to be used by Apache Beam BigtableIO. Reads changes from a table's change stream. Changes will reflect both user-initiated mutations and mutations that are caused by garbage collection.
1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 1218 def read_change_stream request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::ReadChangeStreamRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.read_change_stream..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::V2::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.table_name header_params["table_name"] = request.table_name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.read_change_stream.timeout, metadata: , retry_policy: @config.rpcs.read_change_stream.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @bigtable_stub.call_rpc :read_change_stream, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#read_modify_write_row(request, options = nil) ⇒ ::Google::Cloud::Bigtable::V2::ReadModifyWriteRowResponse #read_modify_write_row(table_name: nil, authorized_view_name: nil, app_profile_id: nil, row_key: nil, rules: nil) ⇒ ::Google::Cloud::Bigtable::V2::ReadModifyWriteRowResponse
Modifies a row atomically on the server. The method reads the latest existing timestamp and value from the specified columns and writes a new entry based on pre-defined read/modify/write rules. The new value for the timestamp is the greater of the existing timestamp or the current server time. The method returns the new contents of all modified cells.
985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 985 def read_modify_write_row request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::ReadModifyWriteRowRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.read_modify_write_row..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::V2::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.table_name && %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/?$}.match?(request.table_name) header_params["table_name"] = request.table_name end if request.app_profile_id && !request.app_profile_id.empty? header_params["app_profile_id"] = request.app_profile_id end if request. && %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/authorizedViews/[^/]+/?$}.match?(request.) header_params["authorized_view_name"] = request. end request_params_header = URI.encode_www_form header_params [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.read_modify_write_row.timeout, metadata: , retry_policy: @config.rpcs.read_modify_write_row.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @bigtable_stub.call_rpc :read_modify_write_row, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#read_rows(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ReadRowsResponse> #read_rows(table_name: nil, authorized_view_name: nil, materialized_view_name: nil, app_profile_id: nil, rows: nil, filter: nil, rows_limit: nil, request_stats_view: nil, reversed: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ReadRowsResponse>
Streams back the contents of all requested rows in key order, optionally applying the same Reader filter to each. Depending on their size, rows and cells may be broken up across multiple responses, but atomicity of each row will still be preserved. See the ReadRowsResponse documentation for details.
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 301 def read_rows request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::ReadRowsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.read_rows..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::V2::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.table_name && %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/?$}.match?(request.table_name) header_params["table_name"] = request.table_name end if request.app_profile_id && !request.app_profile_id.empty? header_params["app_profile_id"] = request.app_profile_id end if request. && %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/authorizedViews/[^/]+/?$}.match?(request.) header_params["authorized_view_name"] = request. end request_params_header = URI.encode_www_form header_params [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.read_rows.timeout, metadata: , retry_policy: @config.rpcs.read_rows.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @bigtable_stub.call_rpc :read_rows, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#sample_row_keys(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::SampleRowKeysResponse> #sample_row_keys(table_name: nil, authorized_view_name: nil, materialized_view_name: nil, app_profile_id: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::SampleRowKeysResponse>
Returns a sample of row keys in the table. The returned row keys will delimit contiguous sections of the table of approximately equal size, which can be used to break up the data for distributed tasks like mapreduces.
417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 417 def sample_row_keys request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::SampleRowKeysRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.sample_row_keys..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::V2::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.table_name && %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/?$}.match?(request.table_name) header_params["table_name"] = request.table_name end if request.app_profile_id && !request.app_profile_id.empty? header_params["app_profile_id"] = request.app_profile_id end if request. && %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/authorizedViews/[^/]+/?$}.match?(request.) header_params["authorized_view_name"] = request. end request_params_header = URI.encode_www_form header_params [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.sample_row_keys.timeout, metadata: , retry_policy: @config.rpcs.sample_row_keys.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @bigtable_stub.call_rpc :sample_row_keys, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#universe_domain ⇒ String
The effective universe domain
128 129 130 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 128 def universe_domain @bigtable_stub.universe_domain end |