Module: Google::Cloud::Bigtable::V2::CloseSessionRequest::CloseSessionReason

Defined in:
proto_docs/google/bigtable/v2/session.rb

Overview

Client-generated reason for terminating the session, including a plain-text description of why. 'reason' may be used for metrics, while both may be logged (server-side).

Constant Summary collapse

CLOSE_SESSION_REASON_UNSET =
0
CLOSE_SESSION_REASON_GOAWAY =
1
CLOSE_SESSION_REASON_ERROR =
2
CLOSE_SESSION_REASON_USER =
3
CLOSE_SESSION_REASON_DOWNSIZE =
4
CLOSE_SESSION_REASON_MISSED_HEARTBEAT =
5