Class: Google::Cloud::Bigtable::V2::ExecuteQueryRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/bigtable/v2/bigtable.rb

Overview

Request message for Bigtable.ExecuteQuery

Defined Under Namespace

Classes: ParamsEntry, ViewParametersEntry

Instance Attribute Summary collapse

Instance Attribute Details

#app_profile_id::String

Returns Optional. This value specifies routing for replication. If not specified, the default application profile will be used.

Returns:

  • (::String)

    Optional. This value specifies routing for replication. If not specified, the default application profile will be used.



848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 848

class ExecuteQueryRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Bigtable::V2::Value]
  class ParamsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Bigtable::V2::Value]
  class ViewParametersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#instance_name::String

Returns Required. The unique name of the instance against which the query should be executed. Values are of the form projects/<project>/instances/<instance>.

Returns:

  • (::String)

    Required. The unique name of the instance against which the query should be executed. Values are of the form projects/<project>/instances/<instance>



848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 848

class ExecuteQueryRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Bigtable::V2::Value]
  class ParamsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Bigtable::V2::Value]
  class ViewParametersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#params::Google::Protobuf::Map{::String => ::Google::Cloud::Bigtable::V2::Value}

Returns Required. params contains string type keys and Bigtable type values that bind to placeholders in the query string. In query string, a parameter placeholder consists of the @ character followed by the parameter name (for example, @firstName) in the query string.

For example, if params["firstName"] = bytes_value: "foo" type {bytes_type {}} then @firstName will be replaced with googlesql bytes value "foo" in the query string during query evaluation.

If Value.kind is not set, the value is treated as a NULL value of the given type. For example, if params["firstName"] = type {string_type {}} then @firstName will be replaced with googlesql null string.

If query is set, any empty Value.type in the map will be rejected with INVALID_ARGUMENT.

If prepared_query is set, any empty Value.type in the map will be inferred from the param_types in the PrepareQueryRequest. Any non-empty Value.type must match the corresponding param_types entry, or be rejected with INVALID_ARGUMENT.

Returns:

  • (::Google::Protobuf::Map{::String => ::Google::Cloud::Bigtable::V2::Value})

    Required. params contains string type keys and Bigtable type values that bind to placeholders in the query string. In query string, a parameter placeholder consists of the @ character followed by the parameter name (for example, @firstName) in the query string.

    For example, if params["firstName"] = bytes_value: "foo" type {bytes_type {}} then @firstName will be replaced with googlesql bytes value "foo" in the query string during query evaluation.

    If Value.kind is not set, the value is treated as a NULL value of the given type. For example, if params["firstName"] = type {string_type {}} then @firstName will be replaced with googlesql null string.

    If query is set, any empty Value.type in the map will be rejected with INVALID_ARGUMENT.

    If prepared_query is set, any empty Value.type in the map will be inferred from the param_types in the PrepareQueryRequest. Any non-empty Value.type must match the corresponding param_types entry, or be rejected with INVALID_ARGUMENT.



848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 848

class ExecuteQueryRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Bigtable::V2::Value]
  class ParamsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Bigtable::V2::Value]
  class ViewParametersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#prepared_query::String

Returns A prepared query that was returned from PrepareQueryResponse.

Exactly one of query and prepared_query is required. Setting both or neither is an INVALID_ARGUMENT.

Setting this field also places restrictions on several other fields:

  • data_format must be empty.
  • validate_only must be false.
  • params must match the param_types set in the PrepareQueryRequest.

Returns:

  • (::String)

    A prepared query that was returned from PrepareQueryResponse.

    Exactly one of query and prepared_query is required. Setting both or neither is an INVALID_ARGUMENT.

    Setting this field also places restrictions on several other fields:

    • data_format must be empty.
    • validate_only must be false.
    • params must match the param_types set in the PrepareQueryRequest.


848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 848

class ExecuteQueryRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Bigtable::V2::Value]
  class ParamsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Bigtable::V2::Value]
  class ViewParametersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#proto_format::Google::Cloud::Bigtable::V2::ProtoFormat

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Protocol buffer format as described by ProtoSchema and ProtoRows messages.

Returns:



848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 848

class ExecuteQueryRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Bigtable::V2::Value]
  class ParamsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Bigtable::V2::Value]
  class ViewParametersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#query::String

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Required. The query string.

Exactly one of query and prepared_query is required. Setting both or neither is an INVALID_ARGUMENT.

Returns:

  • (::String)

    Required. The query string.

    Exactly one of query and prepared_query is required. Setting both or neither is an INVALID_ARGUMENT.



848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 848

class ExecuteQueryRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Bigtable::V2::Value]
  class ParamsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Bigtable::V2::Value]
  class ViewParametersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#resume_token::String

Returns Optional. If this request is resuming a previously interrupted query execution, resume_token should be copied from the last PartialResultSet yielded before the interruption. Doing this enables the query execution to resume where the last one left off. The rest of the request parameters must exactly match the request that yielded this token. Otherwise the request will fail.

Returns:

  • (::String)

    Optional. If this request is resuming a previously interrupted query execution, resume_token should be copied from the last PartialResultSet yielded before the interruption. Doing this enables the query execution to resume where the last one left off. The rest of the request parameters must exactly match the request that yielded this token. Otherwise the request will fail.



848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 848

class ExecuteQueryRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Bigtable::V2::Value]
  class ParamsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Bigtable::V2::Value]
  class ViewParametersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#view_parameters::Google::Protobuf::Map{::String => ::Google::Cloud::Bigtable::V2::Value}

Returns Optional. This map provides the runtime values returned by the VIEW_PARAMETERS() function calls, typically used for user-level scoping of data based on identity.

The key is the name of the view parameter e.g. user_id, and the value is the parameter value e.g. alice@example.com.

Returns:

  • (::Google::Protobuf::Map{::String => ::Google::Cloud::Bigtable::V2::Value})

    Optional. This map provides the runtime values returned by the VIEW_PARAMETERS() function calls, typically used for user-level scoping of data based on identity.

    The key is the name of the view parameter e.g. user_id, and the value is the parameter value e.g. alice@example.com.



848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 848

class ExecuteQueryRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Bigtable::V2::Value]
  class ParamsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Bigtable::V2::Value]
  class ViewParametersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end