Class: Google::Cloud::Bigtable::V2::FeatureFlags
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::FeatureFlags
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/feature_flags.rb
Overview
Feature flags supported or enabled by a client.
This is intended to be sent as part of request metadata to assure the server
that certain behaviors are safe to enable. This proto is meant to be
serialized and websafe-base64 encoded under the bigtable-features metadata
key. The value will remain constant for the lifetime of a client and due to
HTTP2's HPACK compression, the request overhead will be tiny.
This is an internal implementation detail and should not be used by end users
directly.
Instance Attribute Summary collapse
-
#client_side_metrics_enabled ⇒ ::Boolean
Notify the server that the client has client side metrics enabled.
-
#direct_access_requested ⇒ ::Boolean
Notify the server that the client explicitly opted in for Direct Access.
-
#last_scanned_row_responses ⇒ ::Boolean
Notify the server that the client supports the last_scanned_row field in ReadRowsResponse for long-running scans.
-
#mutate_rows_rate_limit ⇒ ::Boolean
Notify the server that the client enables batch write flow control by requesting RateLimitInfo from MutateRowsResponse.
-
#mutate_rows_rate_limit2 ⇒ ::Boolean
Notify the server that the client enables batch write flow control by requesting RateLimitInfo from MutateRowsResponse.
-
#peer_info ⇒ ::Boolean
If the client can support using BigtablePeerInfo.
-
#retry_info ⇒ ::Boolean
Notify the server that the client supports using retry info back off durations to retry requests with.
-
#reverse_scans ⇒ ::Boolean
Notify the server that the client supports reverse scans.
-
#routing_cookie ⇒ ::Boolean
Notify the server that the client supports using encoded routing cookie strings to retry requests with.
-
#sessions_compatible ⇒ ::Boolean
Indicates whether the client supports the Bigtable Sessions API.
-
#sessions_required ⇒ ::Boolean
Internal flag to force sessions for internal projects.
-
#traffic_director_enabled ⇒ ::Boolean
Notify the server that the client using Traffic Director endpoint.
Instance Attribute Details
#client_side_metrics_enabled ⇒ ::Boolean
Returns Notify the server that the client has client side metrics enabled.
76 77 78 79 |
# File 'proto_docs/google/bigtable/v2/feature_flags.rb', line 76 class FeatureFlags include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#direct_access_requested ⇒ ::Boolean
Returns Notify the server that the client explicitly opted in for Direct Access.
76 77 78 79 |
# File 'proto_docs/google/bigtable/v2/feature_flags.rb', line 76 class FeatureFlags include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#last_scanned_row_responses ⇒ ::Boolean
Returns Notify the server that the client supports the last_scanned_row field in ReadRowsResponse for long-running scans.
76 77 78 79 |
# File 'proto_docs/google/bigtable/v2/feature_flags.rb', line 76 class FeatureFlags include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#mutate_rows_rate_limit ⇒ ::Boolean
Returns Notify the server that the client enables batch write flow control by requesting RateLimitInfo from MutateRowsResponse. Due to technical reasons, this disables partial retries.
76 77 78 79 |
# File 'proto_docs/google/bigtable/v2/feature_flags.rb', line 76 class FeatureFlags include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#mutate_rows_rate_limit2 ⇒ ::Boolean
Returns Notify the server that the client enables batch write flow control by requesting RateLimitInfo from MutateRowsResponse. With partial retries enabled.
76 77 78 79 |
# File 'proto_docs/google/bigtable/v2/feature_flags.rb', line 76 class FeatureFlags include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#peer_info ⇒ ::Boolean
Returns If the client can support using BigtablePeerInfo.
76 77 78 79 |
# File 'proto_docs/google/bigtable/v2/feature_flags.rb', line 76 class FeatureFlags include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#retry_info ⇒ ::Boolean
Returns Notify the server that the client supports using retry info back off durations to retry requests with.
76 77 78 79 |
# File 'proto_docs/google/bigtable/v2/feature_flags.rb', line 76 class FeatureFlags include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#reverse_scans ⇒ ::Boolean
Returns Notify the server that the client supports reverse scans. The server will reject ReadRowsRequests with the reverse bit set when this is absent.
76 77 78 79 |
# File 'proto_docs/google/bigtable/v2/feature_flags.rb', line 76 class FeatureFlags include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#routing_cookie ⇒ ::Boolean
Returns Notify the server that the client supports using encoded routing cookie strings to retry requests with.
76 77 78 79 |
# File 'proto_docs/google/bigtable/v2/feature_flags.rb', line 76 class FeatureFlags include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sessions_compatible ⇒ ::Boolean
Returns Indicates whether the client supports the Bigtable Sessions API.
76 77 78 79 |
# File 'proto_docs/google/bigtable/v2/feature_flags.rb', line 76 class FeatureFlags include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sessions_required ⇒ ::Boolean
Returns Internal flag to force sessions for internal projects.
76 77 78 79 |
# File 'proto_docs/google/bigtable/v2/feature_flags.rb', line 76 class FeatureFlags include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#traffic_director_enabled ⇒ ::Boolean
Returns Notify the server that the client using Traffic Director endpoint.
76 77 78 79 |
# File 'proto_docs/google/bigtable/v2/feature_flags.rb', line 76 class FeatureFlags include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |