Class: Google::Cloud::Bigtable::V2::GetClientConfigurationRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/bigtable/v2/session.rb

Overview

See GetClientConfiguration() RPC in bigtable.proto. Internal usage only.

Instance Attribute Summary collapse

Instance Attribute Details

#app_profile_id::String

Returns Optional. The name of the AppProfile which will be used by the client when sending requests in the Data API.

If not specified, the default application profile will be used.

Returns:

  • (::String)

    Optional. The name of the AppProfile which will be used by the client when sending requests in the Data API.

    If not specified, the default application profile will be used.



37
38
39
40
# File 'proto_docs/google/bigtable/v2/session.rb', line 37

class GetClientConfigurationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#instance_name::String

Returns Required. The unique name of the instance for which the client will target with Data API requests.

Values are of the form projects/<project>/instances/<instance>.

Returns:

  • (::String)

    Required. The unique name of the instance for which the client will target with Data API requests.

    Values are of the form projects/<project>/instances/<instance>



37
38
39
40
# File 'proto_docs/google/bigtable/v2/session.rb', line 37

class GetClientConfigurationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end