Class: Google::Cloud::Bigtable::V2::LoadBalancingOptions::PeakEwma

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/bigtable/v2/session.rb

Overview

Balances vRPCs over backends, by maintaining a moving average of each AFE's round-trip time, weighted by the number of outstanding vRPCs, and distribute traffic to AFEs where that cost function is smallest.

See: https://linkerd.io/2016/03/16/beyond-round-robin-load-balancing-for-latency

Instance Attribute Summary collapse

Instance Attribute Details

#random_subset_size::Integer

Returns Of all connected AFEs, the size of the random subset to compare costs over. Zero implies all connected AFEs.

Returns:

  • (::Integer)

    Of all connected AFEs, the size of the random subset to compare costs over. Zero implies all connected AFEs.



77
78
79
80
# File 'proto_docs/google/bigtable/v2/session.rb', line 77

class PeakEwma
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end