Class: Google::Cloud::Bigtable::V2::MutateRowsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::MutateRowsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/bigtable.rb
Overview
Request message for BigtableService.MutateRows.
Defined Under Namespace
Classes: Entry
Instance Attribute Summary collapse
-
#app_profile_id ⇒ ::String
This value specifies routing for replication.
-
#entries ⇒ ::Array<::Google::Cloud::Bigtable::V2::MutateRowsRequest::Entry>
Required.
-
#table_name ⇒ ::String
Required.
Instance Attribute Details
#app_profile_id ⇒ ::String
Returns This value specifies routing for replication. If not specified, the "default" application profile will be used.
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 268 class MutateRowsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A mutation for a given row. # @!attribute [rw] row_key # @return [::String] # The key of the row to which the `mutations` should be applied. # @!attribute [rw] mutations # @return [::Array<::Google::Cloud::Bigtable::V2::Mutation>] # Required. Changes to be atomically applied to the specified row. # Mutations are applied in order, meaning that earlier mutations can be # masked by later ones. You must specify at least one mutation. class Entry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#entries ⇒ ::Array<::Google::Cloud::Bigtable::V2::MutateRowsRequest::Entry>
Returns Required. The row keys and corresponding mutations to be applied in bulk. Each entry is applied as an atomic mutation, but the entries may be applied in arbitrary order (even between entries for the same row). At least one entry must be specified, and in total the entries can contain at most 100000 mutations.
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 268 class MutateRowsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A mutation for a given row. # @!attribute [rw] row_key # @return [::String] # The key of the row to which the `mutations` should be applied. # @!attribute [rw] mutations # @return [::Array<::Google::Cloud::Bigtable::V2::Mutation>] # Required. Changes to be atomically applied to the specified row. # Mutations are applied in order, meaning that earlier mutations can be # masked by later ones. You must specify at least one mutation. class Entry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#table_name ⇒ ::String
Returns Required. The unique name of the table to which the mutations should be applied.
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 268 class MutateRowsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A mutation for a given row. # @!attribute [rw] row_key # @return [::String] # The key of the row to which the `mutations` should be applied. # @!attribute [rw] mutations # @return [::Array<::Google::Cloud::Bigtable::V2::Mutation>] # Required. Changes to be atomically applied to the specified row. # Mutations are applied in order, meaning that earlier mutations can be # masked by later ones. You must specify at least one mutation. class Entry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |