Class: Google::Cloud::Bigtable::V2::MutateRowsRequest::Entry
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::MutateRowsRequest::Entry
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/bigtable.rb
Overview
A mutation for a given row.
Instance Attribute Summary collapse
-
#idempotency ⇒ ::Google::Cloud::Bigtable::V2::Idempotency
If set consistently across retries, prevents this mutation from being double applied to aggregate column families within a 15m window.
-
#mutations ⇒ ::Array<::Google::Cloud::Bigtable::V2::Mutation>
Required.
-
#row_key ⇒ ::String
The key of the row to which the
mutationsshould be applied.
Instance Attribute Details
#idempotency ⇒ ::Google::Cloud::Bigtable::V2::Idempotency
Returns If set consistently across retries, prevents this mutation from being double applied to aggregate column families within a 15m window.
335 336 337 338 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 335 class Entry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#mutations ⇒ ::Array<::Google::Cloud::Bigtable::V2::Mutation>
Returns Required. Changes to be atomically applied to the specified row. Mutations are applied in order, meaning that earlier mutations can be masked by later ones. You must specify at least one mutation.
335 336 337 338 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 335 class Entry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |