Class: Google::Cloud::Bigtable::V2::MutateRowsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::MutateRowsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/bigtable.rb
Overview
Response message for BigtableService.MutateRows.
Defined Under Namespace
Classes: Entry
Instance Attribute Summary collapse
-
#entries ⇒ ::Array<::Google::Cloud::Bigtable::V2::MutateRowsResponse::Entry>
One or more results for Entries from the batch request.
-
#rate_limit_info ⇒ ::Google::Cloud::Bigtable::V2::RateLimitInfo
Information about how client should limit the rate (QPS).
Instance Attribute Details
#entries ⇒ ::Array<::Google::Cloud::Bigtable::V2::MutateRowsResponse::Entry>
Returns One or more results for Entries from the batch request.
350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 350 class MutateRowsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of applying a passed mutation in the original request. # @!attribute [rw] index # @return [::Integer] # The index into the original request's `entries` list of the Entry # for which a result is being reported. # @!attribute [rw] status # @return [::Google::Rpc::Status] # The result of the request Entry identified by `index`. # Depending on how requests are batched during execution, it is possible # for one Entry to fail due to an error with another Entry. In the event # that this occurs, the same error will be reported for both entries. class Entry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#rate_limit_info ⇒ ::Google::Cloud::Bigtable::V2::RateLimitInfo
Returns Information about how client should limit the rate (QPS). Primirily used by supported official Cloud Bigtable clients. If unset, the rate limit info is not provided by the server.
350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 350 class MutateRowsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of applying a passed mutation in the original request. # @!attribute [rw] index # @return [::Integer] # The index into the original request's `entries` list of the Entry # for which a result is being reported. # @!attribute [rw] status # @return [::Google::Rpc::Status] # The result of the request Entry identified by `index`. # Depending on how requests are batched during execution, it is possible # for one Entry to fail due to an error with another Entry. In the event # that this occurs, the same error will be reported for both entries. class Entry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |