Class: Google::Cloud::Bigtable::V2::OpenMaterializedViewRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/bigtable/v2/session.rb

Overview

Open sessions for a MaterializedView. Internal usage only.

Defined Under Namespace

Modules: Permission

Instance Attribute Summary collapse

Instance Attribute Details

#app_profile_id::String

Returns The app profile id to use for the materialized view sessions.

Returns:

  • (::String)

    The app profile id to use for the materialized view sessions.



502
503
504
505
506
507
508
509
510
511
# File 'proto_docs/google/bigtable/v2/session.rb', line 502

class OpenMaterializedViewRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  module Permission
    PERMISSION_UNSET = 0

    PERMISSION_READ = 1
  end
end

#materialized_view_name::String

Returns The Materialized view name to read and write from. Values are of the form projects/<project>/instances/<instance>/materializedViews/<materialized_view>.

Returns:

  • (::String)

    The Materialized view name to read and write from. Values are of the form projects/<project>/instances/<instance>/materializedViews/<materialized_view>.



502
503
504
505
506
507
508
509
510
511
# File 'proto_docs/google/bigtable/v2/session.rb', line 502

class OpenMaterializedViewRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  module Permission
    PERMISSION_UNSET = 0

    PERMISSION_READ = 1
  end
end

#permission::Google::Cloud::Bigtable::V2::OpenMaterializedViewRequest::Permission

Returns Permission for the session.



502
503
504
505
506
507
508
509
510
511
# File 'proto_docs/google/bigtable/v2/session.rb', line 502

class OpenMaterializedViewRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  module Permission
    PERMISSION_UNSET = 0

    PERMISSION_READ = 1
  end
end