Class: Google::Cloud::Bigtable::V2::OpenSessionRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/bigtable/v2/session.rb

Overview

Internal usage only.

Instance Attribute Summary collapse

Instance Attribute Details

#consecutive_failed_connection_attempts::Integer

Returns Used for serverside observability.

Returns:

  • (::Integer)

    Used for serverside observability.



366
367
368
369
# File 'proto_docs/google/bigtable/v2/session.rb', line 366

class OpenSessionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#flags::Google::Cloud::Bigtable::V2::FeatureFlags

Returns Client settings, including a record of.

Returns:



366
367
368
369
# File 'proto_docs/google/bigtable/v2/session.rb', line 366

class OpenSessionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#payload::String

Returns Can be Open{Table,AuthorizedView,MaterializedView}Request, (or in post-V1, PrepareSqlQueryRequest).

Returns:

  • (::String)

    Can be Open{Table,AuthorizedView,MaterializedView}Request, (or in post-V1, PrepareSqlQueryRequest)



366
367
368
369
# File 'proto_docs/google/bigtable/v2/session.rb', line 366

class OpenSessionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#protocol_version::Integer

Returns A version indicator from the client stating its understanding of the protocol. This is to disambiguate client behavior amidst changes in semantic usage of the API, e.g. if the structure remains the same but behavior changes.

Returns:

  • (::Integer)

    A version indicator from the client stating its understanding of the protocol. This is to disambiguate client behavior amidst changes in semantic usage of the API, e.g. if the structure remains the same but behavior changes.



366
367
368
369
# File 'proto_docs/google/bigtable/v2/session.rb', line 366

class OpenSessionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

Returns How the request should be routed (if presented as part of a GOAWAY from a previous session). Post V1.

Returns:

  • (::String)

    How the request should be routed (if presented as part of a GOAWAY from a previous session). Post V1.



366
367
368
369
# File 'proto_docs/google/bigtable/v2/session.rb', line 366

class OpenSessionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end