Class: Google::Cloud::Bigtable::V2::PeerInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::PeerInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/peer_info.rb
Overview
PeerInfo contains information about the peer that the client is connecting to.
Defined Under Namespace
Modules: TransportType
Instance Attribute Summary collapse
-
#application_frontend_id ⇒ ::Integer
An opaque identifier for the application frontend which serviced this request.
-
#application_frontend_region ⇒ ::String
The Cloud region of the application frontend that served this request.
-
#application_frontend_subzone ⇒ ::String
The subzone of the application frontend that served this request, e.g.
-
#application_frontend_zone ⇒ ::String
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#google_frontend_id ⇒ ::Integer
An opaque identifier for the Google Frontend which serviced this request.
- #transport_type ⇒ ::Google::Cloud::Bigtable::V2::PeerInfo::TransportType
Instance Attribute Details
#application_frontend_id ⇒ ::Integer
Returns An opaque identifier for the application frontend which serviced this request.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'proto_docs/google/bigtable/v2/peer_info.rb', line 48 class PeerInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The transport type that the client used to connect to this peer. module TransportType # The transport type is unknown. TRANSPORT_TYPE_UNKNOWN = 0 # The client connected to this peer via an external network # (e.g. outside Google Coud). TRANSPORT_TYPE_EXTERNAL = 1 # The client connected to this peer via CloudPath. TRANSPORT_TYPE_CLOUD_PATH = 2 # The client connected to this peer via DirectAccess. TRANSPORT_TYPE_DIRECT_ACCESS = 3 # The client connected to this peer via Bigtable Sessions using an unknown # transport type. TRANSPORT_TYPE_SESSION_UNKNOWN = 4 # The client connected to this peer via Bigtable Sessions on an external # network (e.g. outside Google Cloud). TRANSPORT_TYPE_SESSION_EXTERNAL = 5 # The client connected to this peer via Bigtable Sessions using CloudPath. TRANSPORT_TYPE_SESSION_CLOUD_PATH = 6 # The client connected to this peer via Bigtable Sessions using # DirectAccess. TRANSPORT_TYPE_SESSION_DIRECT_ACCESS = 7 end end |
#application_frontend_region ⇒ ::String
Returns The Cloud region of the application frontend that served this request.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'proto_docs/google/bigtable/v2/peer_info.rb', line 48 class PeerInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The transport type that the client used to connect to this peer. module TransportType # The transport type is unknown. TRANSPORT_TYPE_UNKNOWN = 0 # The client connected to this peer via an external network # (e.g. outside Google Coud). TRANSPORT_TYPE_EXTERNAL = 1 # The client connected to this peer via CloudPath. TRANSPORT_TYPE_CLOUD_PATH = 2 # The client connected to this peer via DirectAccess. TRANSPORT_TYPE_DIRECT_ACCESS = 3 # The client connected to this peer via Bigtable Sessions using an unknown # transport type. TRANSPORT_TYPE_SESSION_UNKNOWN = 4 # The client connected to this peer via Bigtable Sessions on an external # network (e.g. outside Google Cloud). TRANSPORT_TYPE_SESSION_EXTERNAL = 5 # The client connected to this peer via Bigtable Sessions using CloudPath. TRANSPORT_TYPE_SESSION_CLOUD_PATH = 6 # The client connected to this peer via Bigtable Sessions using # DirectAccess. TRANSPORT_TYPE_SESSION_DIRECT_ACCESS = 7 end end |
#application_frontend_subzone ⇒ ::String
Returns The subzone of the application frontend that served this request, e.g. an identifier for where within a zone (within the reported region) the application frontend is.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'proto_docs/google/bigtable/v2/peer_info.rb', line 48 class PeerInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The transport type that the client used to connect to this peer. module TransportType # The transport type is unknown. TRANSPORT_TYPE_UNKNOWN = 0 # The client connected to this peer via an external network # (e.g. outside Google Coud). TRANSPORT_TYPE_EXTERNAL = 1 # The client connected to this peer via CloudPath. TRANSPORT_TYPE_CLOUD_PATH = 2 # The client connected to this peer via DirectAccess. TRANSPORT_TYPE_DIRECT_ACCESS = 3 # The client connected to this peer via Bigtable Sessions using an unknown # transport type. TRANSPORT_TYPE_SESSION_UNKNOWN = 4 # The client connected to this peer via Bigtable Sessions on an external # network (e.g. outside Google Cloud). TRANSPORT_TYPE_SESSION_EXTERNAL = 5 # The client connected to this peer via Bigtable Sessions using CloudPath. TRANSPORT_TYPE_SESSION_CLOUD_PATH = 6 # The client connected to this peer via Bigtable Sessions using # DirectAccess. TRANSPORT_TYPE_SESSION_DIRECT_ACCESS = 7 end end |
#application_frontend_zone ⇒ ::String
This field is deprecated and may be removed in the next major version update.
Returns The Cloud zone of the application frontend that served this request.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'proto_docs/google/bigtable/v2/peer_info.rb', line 48 class PeerInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The transport type that the client used to connect to this peer. module TransportType # The transport type is unknown. TRANSPORT_TYPE_UNKNOWN = 0 # The client connected to this peer via an external network # (e.g. outside Google Coud). TRANSPORT_TYPE_EXTERNAL = 1 # The client connected to this peer via CloudPath. TRANSPORT_TYPE_CLOUD_PATH = 2 # The client connected to this peer via DirectAccess. TRANSPORT_TYPE_DIRECT_ACCESS = 3 # The client connected to this peer via Bigtable Sessions using an unknown # transport type. TRANSPORT_TYPE_SESSION_UNKNOWN = 4 # The client connected to this peer via Bigtable Sessions on an external # network (e.g. outside Google Cloud). TRANSPORT_TYPE_SESSION_EXTERNAL = 5 # The client connected to this peer via Bigtable Sessions using CloudPath. TRANSPORT_TYPE_SESSION_CLOUD_PATH = 6 # The client connected to this peer via Bigtable Sessions using # DirectAccess. TRANSPORT_TYPE_SESSION_DIRECT_ACCESS = 7 end end |
#google_frontend_id ⇒ ::Integer
Returns An opaque identifier for the Google Frontend which serviced this request. Only set when not using DirectAccess.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'proto_docs/google/bigtable/v2/peer_info.rb', line 48 class PeerInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The transport type that the client used to connect to this peer. module TransportType # The transport type is unknown. TRANSPORT_TYPE_UNKNOWN = 0 # The client connected to this peer via an external network # (e.g. outside Google Coud). TRANSPORT_TYPE_EXTERNAL = 1 # The client connected to this peer via CloudPath. TRANSPORT_TYPE_CLOUD_PATH = 2 # The client connected to this peer via DirectAccess. TRANSPORT_TYPE_DIRECT_ACCESS = 3 # The client connected to this peer via Bigtable Sessions using an unknown # transport type. TRANSPORT_TYPE_SESSION_UNKNOWN = 4 # The client connected to this peer via Bigtable Sessions on an external # network (e.g. outside Google Cloud). TRANSPORT_TYPE_SESSION_EXTERNAL = 5 # The client connected to this peer via Bigtable Sessions using CloudPath. TRANSPORT_TYPE_SESSION_CLOUD_PATH = 6 # The client connected to this peer via Bigtable Sessions using # DirectAccess. TRANSPORT_TYPE_SESSION_DIRECT_ACCESS = 7 end end |
#transport_type ⇒ ::Google::Cloud::Bigtable::V2::PeerInfo::TransportType
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'proto_docs/google/bigtable/v2/peer_info.rb', line 48 class PeerInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The transport type that the client used to connect to this peer. module TransportType # The transport type is unknown. TRANSPORT_TYPE_UNKNOWN = 0 # The client connected to this peer via an external network # (e.g. outside Google Coud). TRANSPORT_TYPE_EXTERNAL = 1 # The client connected to this peer via CloudPath. TRANSPORT_TYPE_CLOUD_PATH = 2 # The client connected to this peer via DirectAccess. TRANSPORT_TYPE_DIRECT_ACCESS = 3 # The client connected to this peer via Bigtable Sessions using an unknown # transport type. TRANSPORT_TYPE_SESSION_UNKNOWN = 4 # The client connected to this peer via Bigtable Sessions on an external # network (e.g. outside Google Cloud). TRANSPORT_TYPE_SESSION_EXTERNAL = 5 # The client connected to this peer via Bigtable Sessions using CloudPath. TRANSPORT_TYPE_SESSION_CLOUD_PATH = 6 # The client connected to this peer via Bigtable Sessions using # DirectAccess. TRANSPORT_TYPE_SESSION_DIRECT_ACCESS = 7 end end |