Class: Google::Cloud::Bigtable::V2::PrepareQueryRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::PrepareQueryRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/bigtable.rb
Overview
Request message for Bigtable.PrepareQuery
Defined Under Namespace
Classes: ParamTypesEntry
Instance Attribute Summary collapse
-
#app_profile_id ⇒ ::String
Optional.
-
#instance_name ⇒ ::String
Required.
-
#param_types ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Bigtable::V2::Type}
Required.
-
#proto_format ⇒ ::Google::Cloud::Bigtable::V2::ProtoFormat
Protocol buffer format as described by ProtoSchema and ProtoRows messages.
-
#query ⇒ ::String
Required.
Instance Attribute Details
#app_profile_id ⇒ ::String
Returns Optional. This value specifies routing for preparing the query. Note that
this app_profile_id is only used for preparing the query. The actual
query execution will use the app profile specified in the
ExecuteQueryRequest. If not specified, the default application profile
will be used.
932 933 934 935 936 937 938 939 940 941 942 943 944 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 932 class PrepareQueryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Bigtable::V2::Type] class ParamTypesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#instance_name ⇒ ::String
Returns Required. The unique name of the instance against which the query should be
executed.
Values are of the form projects/<project>/instances/<instance>.
932 933 934 935 936 937 938 939 940 941 942 943 944 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 932 class PrepareQueryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Bigtable::V2::Type] class ParamTypesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#param_types ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Bigtable::V2::Type}
Returns Required. param_types is a map of parameter identifier strings to their
Types.
In query string, a parameter placeholder consists of the
@ character followed by the parameter name (for example, @firstName) in
the query string.
For example, if param_types["firstName"] = Bytes then @firstName will be a
query parameter of type Bytes. The specific Value to be used for the
query execution must be sent in ExecuteQueryRequest in the params map.
932 933 934 935 936 937 938 939 940 941 942 943 944 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 932 class PrepareQueryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Bigtable::V2::Type] class ParamTypesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#proto_format ⇒ ::Google::Cloud::Bigtable::V2::ProtoFormat
Returns Protocol buffer format as described by ProtoSchema and ProtoRows messages.
932 933 934 935 936 937 938 939 940 941 942 943 944 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 932 class PrepareQueryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Bigtable::V2::Type] class ParamTypesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#query ⇒ ::String
Returns Required. The query string.
932 933 934 935 936 937 938 939 940 941 942 943 944 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 932 class PrepareQueryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Bigtable::V2::Type] class ParamTypesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |