Class: Google::Cloud::Bigtable::V2::ReadEfficiencyStats
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::ReadEfficiencyStats
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/request_stats.rb
Overview
ReadEfficiencyStats captures information about the efficiency of a read.
Instance Attribute Summary collapse
-
#read_iterator_stats ⇒ ::Google::Cloud::Bigtable::V2::ReadIteratorStats
Iteration stats describe how efficient the read is, e.g.
-
#request_latency_stats ⇒ ::Google::Cloud::Bigtable::V2::RequestLatencyStats
Request latency stats describe the time taken to complete a request, from the server side.
Instance Attribute Details
#read_iterator_stats ⇒ ::Google::Cloud::Bigtable::V2::ReadIteratorStats
Returns Iteration stats describe how efficient the read is, e.g. comparing rows seen vs. rows returned or cells seen vs cells returned can provide an indication of read efficiency (the higher the ratio of seen to retuned the better).
80 81 82 83 |
# File 'proto_docs/google/bigtable/v2/request_stats.rb', line 80 class ReadEfficiencyStats include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_latency_stats ⇒ ::Google::Cloud::Bigtable::V2::RequestLatencyStats
Returns Request latency stats describe the time taken to complete a request, from the server side.
80 81 82 83 |
# File 'proto_docs/google/bigtable/v2/request_stats.rb', line 80 class ReadEfficiencyStats include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |