Class: Google::Cloud::Bigtable::V2::ReadModifyWriteRowRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::ReadModifyWriteRowRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/bigtable.rb
Overview
Request message for Bigtable.ReadModifyWriteRow.
Instance Attribute Summary collapse
-
#app_profile_id ⇒ ::String
This value specifies routing for replication.
-
#authorized_view_name ⇒ ::String
Optional.
-
#row_key ⇒ ::String
Required.
-
#rules ⇒ ::Array<::Google::Cloud::Bigtable::V2::ReadModifyWriteRule>
Required.
-
#table_name ⇒ ::String
Optional.
Instance Attribute Details
#app_profile_id ⇒ ::String
Returns This value specifies routing for replication. If not specified, the "default" application profile will be used.
504 505 506 507 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 504 class ReadModifyWriteRowRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#authorized_view_name ⇒ ::String
Returns Optional. The unique name of the AuthorizedView to which the read/modify/write rules should be applied.
Values are of the form
projects/<project>/instances/<instance>/tables/<table>/authorizedViews/<authorized_view>.
504 505 506 507 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 504 class ReadModifyWriteRowRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#row_key ⇒ ::String
Returns Required. The key of the row to which the read/modify/write rules should be applied.
504 505 506 507 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 504 class ReadModifyWriteRowRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#rules ⇒ ::Array<::Google::Cloud::Bigtable::V2::ReadModifyWriteRule>
Returns Required. Rules specifying how the specified row's contents are to be transformed into writes. Entries are applied in order, meaning that earlier rules will affect the results of later ones. At least one entry must be specified, and there can be at most 100000 rules.
504 505 506 507 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 504 class ReadModifyWriteRowRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#table_name ⇒ ::String
Returns Optional. The unique name of the table to which the read/modify/write rules should be applied.
Values are of the form
projects/<project>/instances/<instance>/tables/<table>.
504 505 506 507 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 504 class ReadModifyWriteRowRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |