Class: Google::Cloud::Bigtable::V2::RequestLatencyStats

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/bigtable/v2/request_stats.rb

Overview

RequestLatencyStats provides a measurement of the latency of the request as it interacts with different systems over its lifetime, e.g. how long the request took to execute within a frontend server.

Instance Attribute Summary collapse

Instance Attribute Details

#frontend_server_latency::Google::Protobuf::Duration

Returns The latency measured by the frontend server handling this request, from when the request was received, to when this value is sent back in the response. For more context on the component that is measuring this latency, see: https://cloud.google.com/bigtable/docs/overview

Note: This value may be slightly shorter than the value reported into aggregate latency metrics in Monitoring for this request (https://cloud.google.com/bigtable/docs/monitoring-instance) as this value needs to be sent in the response before the latency measurement including that transmission is finalized.

Returns:



64
65
66
67
# File 'proto_docs/google/bigtable/v2/request_stats.rb', line 64

class RequestLatencyStats
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end