Class: Google::Cloud::Bigtable::V2::RequestStats
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::RequestStats
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/request_stats.rb
Overview
RequestStats is the container for additional information pertaining to a single request, helpful for evaluating the performance of the sent request. Currently, there are the following supported methods:
- google.bigtable.v2.ReadRows
Instance Attribute Summary collapse
-
#all_read_stats ⇒ ::Google::Cloud::Bigtable::V2::AllReadStats
Available with the ReadRowsRequest.RequestStatsView.REQUEST_STATS_FULL view, see package google.bigtable.v2.
-
#read_efficiency_stats ⇒ ::Google::Cloud::Bigtable::V2::ReadEfficiencyStats
Available with the ReadRowsRequest.RequestStatsView.REQUEST_STATS_EFFICIENCY view, see package google.bigtable.v2.
Instance Attribute Details
#all_read_stats ⇒ ::Google::Cloud::Bigtable::V2::AllReadStats
Returns Available with the ReadRowsRequest.RequestStatsView.REQUEST_STATS_FULL view, see package google.bigtable.v2.
114 115 116 117 |
# File 'proto_docs/google/bigtable/v2/request_stats.rb', line 114 class RequestStats include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#read_efficiency_stats ⇒ ::Google::Cloud::Bigtable::V2::ReadEfficiencyStats
Returns Available with the ReadRowsRequest.RequestStatsView.REQUEST_STATS_EFFICIENCY view, see package google.bigtable.v2.
114 115 116 117 |
# File 'proto_docs/google/bigtable/v2/request_stats.rb', line 114 class RequestStats include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |