Class: Google::Cloud::Bigtable::V2::SampleRowKeysResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::SampleRowKeysResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/bigtable.rb
Overview
Response message for Bigtable.SampleRowKeys.
Instance Attribute Summary collapse
-
#offset_bytes ⇒ ::Integer
Approximate total storage space used by all rows in the table which precede
row_key(and if a row-range is specified in the request, which follow what would have been the previous sample before the row-range start). -
#row_key ⇒ ::String
Sorted streamed sequence of sample row keys in the table, restricted to the row_range if specified in the request.
Instance Attribute Details
#offset_bytes ⇒ ::Integer
Returns Approximate total storage space used by all rows in the table which precede
row_key (and if a row-range is specified in the request, which follow
what would have been the previous sample before the row-range start).
Buffering the contents of all rows between two subsequent
samples would require space roughly equal to the difference in their
offset_bytes fields.
245 246 247 248 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 245 class SampleRowKeysResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#row_key ⇒ ::String
Returns Sorted streamed sequence of sample row keys in the table, restricted to the row_range if specified in the request. The table might have contents before the first row key in the list and after the last one, but a key containing the empty string indicates "end of table" and will be the last response given, if present and within the row-range specified in the request. Note that row keys in this list may not have ever been written to or read from, and users should therefore not make any assumptions about the row key structure that are specific to their use case.
245 246 247 248 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 245 class SampleRowKeysResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |