Class: Google::Cloud::Bigtable::V2::SessionClientConfiguration::ChannelPoolConfiguration

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/bigtable/v2/session.rb

Overview

Configuration for the channel pool.

Defined Under Namespace

Classes: CloudPathOnly, DirectAccessOnly, DirectAccessWithFallback

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_path_only::Google::Cloud::Bigtable::V2::SessionClientConfiguration::ChannelPoolConfiguration::CloudPathOnly

Returns CloudPath only.

Note: The following fields are mutually exclusive: cloud_path_only, direct_access_with_fallback, direct_access_only. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'proto_docs/google/bigtable/v2/session.rb', line 140

class ChannelPoolConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A channel mode which allows DirectAccess with a fallback to CloudPath if
  # DirectAccess is unavailable.
  # @!attribute [rw] error_rate_threshold
  #   @return [::Float]
  #     The threshold for errors on DirectAccess to trigger CloudPath fallback.
  #     The error rate is calculated based on a count of vRPCs with errors
  #     divided by a total count of vRPCs, over a rolling window of the past
  #     check_interval. If this ratio exceeds this threshold, the fallback to
  #     CloudPath is triggered. [0, 1].
  # @!attribute [rw] check_interval
  #   @return [::Google::Protobuf::Duration]
  #     The interval to check the error rate over.
  class DirectAccessWithFallback
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A channel mode which only allows DirectAccess.
  class DirectAccessOnly
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A channel mode which only allows CloudPath.
  class CloudPathOnly
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#direct_access_only::Google::Cloud::Bigtable::V2::SessionClientConfiguration::ChannelPoolConfiguration::DirectAccessOnly

Returns DirectAccess only.

Note: The following fields are mutually exclusive: direct_access_only, direct_access_with_fallback, cloud_path_only. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'proto_docs/google/bigtable/v2/session.rb', line 140

class ChannelPoolConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A channel mode which allows DirectAccess with a fallback to CloudPath if
  # DirectAccess is unavailable.
  # @!attribute [rw] error_rate_threshold
  #   @return [::Float]
  #     The threshold for errors on DirectAccess to trigger CloudPath fallback.
  #     The error rate is calculated based on a count of vRPCs with errors
  #     divided by a total count of vRPCs, over a rolling window of the past
  #     check_interval. If this ratio exceeds this threshold, the fallback to
  #     CloudPath is triggered. [0, 1].
  # @!attribute [rw] check_interval
  #   @return [::Google::Protobuf::Duration]
  #     The interval to check the error rate over.
  class DirectAccessWithFallback
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A channel mode which only allows DirectAccess.
  class DirectAccessOnly
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A channel mode which only allows CloudPath.
  class CloudPathOnly
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#direct_access_with_fallback::Google::Cloud::Bigtable::V2::SessionClientConfiguration::ChannelPoolConfiguration::DirectAccessWithFallback

Returns DirectAccess with a fallback to CloudPath.

Note: The following fields are mutually exclusive: direct_access_with_fallback, direct_access_only, cloud_path_only. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'proto_docs/google/bigtable/v2/session.rb', line 140

class ChannelPoolConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A channel mode which allows DirectAccess with a fallback to CloudPath if
  # DirectAccess is unavailable.
  # @!attribute [rw] error_rate_threshold
  #   @return [::Float]
  #     The threshold for errors on DirectAccess to trigger CloudPath fallback.
  #     The error rate is calculated based on a count of vRPCs with errors
  #     divided by a total count of vRPCs, over a rolling window of the past
  #     check_interval. If this ratio exceeds this threshold, the fallback to
  #     CloudPath is triggered. [0, 1].
  # @!attribute [rw] check_interval
  #   @return [::Google::Protobuf::Duration]
  #     The interval to check the error rate over.
  class DirectAccessWithFallback
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A channel mode which only allows DirectAccess.
  class DirectAccessOnly
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A channel mode which only allows CloudPath.
  class CloudPathOnly
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#max_server_count::Integer

Returns The maximum number of distinct servers to connect to in the channel pool. The client will ensure that the channel pool will have at most this many distinct servers.

Returns:

  • (::Integer)

    The maximum number of distinct servers to connect to in the channel pool. The client will ensure that the channel pool will have at most this many distinct servers.



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'proto_docs/google/bigtable/v2/session.rb', line 140

class ChannelPoolConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A channel mode which allows DirectAccess with a fallback to CloudPath if
  # DirectAccess is unavailable.
  # @!attribute [rw] error_rate_threshold
  #   @return [::Float]
  #     The threshold for errors on DirectAccess to trigger CloudPath fallback.
  #     The error rate is calculated based on a count of vRPCs with errors
  #     divided by a total count of vRPCs, over a rolling window of the past
  #     check_interval. If this ratio exceeds this threshold, the fallback to
  #     CloudPath is triggered. [0, 1].
  # @!attribute [rw] check_interval
  #   @return [::Google::Protobuf::Duration]
  #     The interval to check the error rate over.
  class DirectAccessWithFallback
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A channel mode which only allows DirectAccess.
  class DirectAccessOnly
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A channel mode which only allows CloudPath.
  class CloudPathOnly
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#min_server_count::Integer

Returns The minimum number of distcint servers to connect to in the channel pool. The client will ensure that the channel pool will have at least this many distinct servers, but may have multiple channels connected to the same server (e.g. the client may have M channels on N machines, where M > N).

Returns:

  • (::Integer)

    The minimum number of distcint servers to connect to in the channel pool. The client will ensure that the channel pool will have at least this many distinct servers, but may have multiple channels connected to the same server (e.g. the client may have M channels on N machines, where M > N).



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'proto_docs/google/bigtable/v2/session.rb', line 140

class ChannelPoolConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A channel mode which allows DirectAccess with a fallback to CloudPath if
  # DirectAccess is unavailable.
  # @!attribute [rw] error_rate_threshold
  #   @return [::Float]
  #     The threshold for errors on DirectAccess to trigger CloudPath fallback.
  #     The error rate is calculated based on a count of vRPCs with errors
  #     divided by a total count of vRPCs, over a rolling window of the past
  #     check_interval. If this ratio exceeds this threshold, the fallback to
  #     CloudPath is triggered. [0, 1].
  # @!attribute [rw] check_interval
  #   @return [::Google::Protobuf::Duration]
  #     The interval to check the error rate over.
  class DirectAccessWithFallback
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A channel mode which only allows DirectAccess.
  class DirectAccessOnly
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A channel mode which only allows CloudPath.
  class CloudPathOnly
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#per_server_session_count::Integer

Returns Soft maximum for how many sessions are allowed per server. Normally, the client will ensure that it does not host more than this count of sessions per server, unless there are other limits encountered (e.g. the connected servers is already at max_servers).

Returns:

  • (::Integer)

    Soft maximum for how many sessions are allowed per server. Normally, the client will ensure that it does not host more than this count of sessions per server, unless there are other limits encountered (e.g. the connected servers is already at max_servers).



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'proto_docs/google/bigtable/v2/session.rb', line 140

class ChannelPoolConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A channel mode which allows DirectAccess with a fallback to CloudPath if
  # DirectAccess is unavailable.
  # @!attribute [rw] error_rate_threshold
  #   @return [::Float]
  #     The threshold for errors on DirectAccess to trigger CloudPath fallback.
  #     The error rate is calculated based on a count of vRPCs with errors
  #     divided by a total count of vRPCs, over a rolling window of the past
  #     check_interval. If this ratio exceeds this threshold, the fallback to
  #     CloudPath is triggered. [0, 1].
  # @!attribute [rw] check_interval
  #   @return [::Google::Protobuf::Duration]
  #     The interval to check the error rate over.
  class DirectAccessWithFallback
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A channel mode which only allows DirectAccess.
  class DirectAccessOnly
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A channel mode which only allows CloudPath.
  class CloudPathOnly
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end