Class: Google::Cloud::Bigtable::V2::SessionClientConfiguration::ChannelPoolConfiguration::DirectAccessWithFallback

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/bigtable/v2/session.rb

Overview

A channel mode which allows DirectAccess with a fallback to CloudPath if DirectAccess is unavailable.

Instance Attribute Summary collapse

Instance Attribute Details

#check_interval::Google::Protobuf::Duration

Returns The interval to check the error rate over.

Returns:



156
157
158
159
# File 'proto_docs/google/bigtable/v2/session.rb', line 156

class DirectAccessWithFallback
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#error_rate_threshold::Float

Returns The threshold for errors on DirectAccess to trigger CloudPath fallback. The error rate is calculated based on a count of vRPCs with errors divided by a total count of vRPCs, over a rolling window of the past check_interval. If this ratio exceeds this threshold, the fallback to CloudPath is triggered. [0, 1].

Returns:

  • (::Float)

    The threshold for errors on DirectAccess to trigger CloudPath fallback. The error rate is calculated based on a count of vRPCs with errors divided by a total count of vRPCs, over a rolling window of the past check_interval. If this ratio exceeds this threshold, the fallback to CloudPath is triggered. [0, 1].



156
157
158
159
# File 'proto_docs/google/bigtable/v2/session.rb', line 156

class DirectAccessWithFallback
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end