Class: Google::Cloud::Bigtable::V2::SessionClientConfiguration::SessionPoolConfiguration

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/bigtable/v2/session.rb

Overview

Configuration for the session pools. Session pools are tied to a scope like a table, an app profile, and a permission.

Instance Attribute Summary collapse

Instance Attribute Details

#consecutive_session_failure_threshold::Integer

Returns A threshold for cancelling all pending vRPCs based on how many consecutive session establishment errors have been observed. The client will eagerly cancel queued vRPCs after this threshold is met to avoid them waiting their entire deadlines before terminating (while waiting for any session to establish to actually send the vRPC).

Returns:

  • (::Integer)

    A threshold for cancelling all pending vRPCs based on how many consecutive session establishment errors have been observed. The client will eagerly cancel queued vRPCs after this threshold is met to avoid them waiting their entire deadlines before terminating (while waiting for any session to establish to actually send the vRPC).



211
212
213
214
# File 'proto_docs/google/bigtable/v2/session.rb', line 211

class SessionPoolConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#headroom::Float

Returns Fraction of idle sessions to keep in order to manage an increase in requests-in-flight. For example, a headroom of 0.5 will keep enough sessions to deal with a 50% increase in QPS.

Returns:

  • (::Float)

    Fraction of idle sessions to keep in order to manage an increase in requests-in-flight. For example, a headroom of 0.5 will keep enough sessions to deal with a 50% increase in QPS.



211
212
213
214
# File 'proto_docs/google/bigtable/v2/session.rb', line 211

class SessionPoolConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#load_balancing_options::Google::Cloud::Bigtable::V2::LoadBalancingOptions

Returns How to balance vRPC load over connections to AFEs. Set only if session_load > 0.

Returns:



211
212
213
214
# File 'proto_docs/google/bigtable/v2/session.rb', line 211

class SessionPoolConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#max_session_count::Integer

Returns The maximum number of sessions for a given scope.

Returns:

  • (::Integer)

    The maximum number of sessions for a given scope.



211
212
213
214
# File 'proto_docs/google/bigtable/v2/session.rb', line 211

class SessionPoolConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#min_session_count::Integer

Returns The minimum number of sessions for a given scope.

Returns:

  • (::Integer)

    The minimum number of sessions for a given scope.



211
212
213
214
# File 'proto_docs/google/bigtable/v2/session.rb', line 211

class SessionPoolConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#new_session_creation_budget::Integer

Returns How many concurrent session establishments are allowed. The client will hold onto a count against this budget whenever it is establishing a new session, and release that count once the session is successfully established or failed to establish.

Returns:

  • (::Integer)

    How many concurrent session establishments are allowed. The client will hold onto a count against this budget whenever it is establishing a new session, and release that count once the session is successfully established or failed to establish.



211
212
213
214
# File 'proto_docs/google/bigtable/v2/session.rb', line 211

class SessionPoolConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#new_session_creation_penalty::Google::Protobuf::Duration

Returns How long to penalize the creation budget for a failed session creation attempt.

Returns:



211
212
213
214
# File 'proto_docs/google/bigtable/v2/session.rb', line 211

class SessionPoolConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#new_session_queue_length::Integer

Returns Number of vRPCs that can be queued per starting session.

Returns:

  • (::Integer)

    Number of vRPCs that can be queued per starting session.



211
212
213
214
# File 'proto_docs/google/bigtable/v2/session.rb', line 211

class SessionPoolConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end