Class: Google::Cloud::Bigtable::V2::SessionParametersResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/bigtable/v2/session.rb

Overview

Internal usage only.

Instance Attribute Summary collapse

Instance Attribute Details

#keep_alive::Google::Protobuf::Duration

Returns Maximum time between messages that the AFE will send to the client. The client may use this information to determine its control-flow in relation to pruning black-holed or otherwise non-responsive sessions. Must be set and positive.

See also Heartbeats.

Returns:

  • (::Google::Protobuf::Duration)

    Maximum time between messages that the AFE will send to the client. The client may use this information to determine its control-flow in relation to pruning black-holed or otherwise non-responsive sessions. Must be set and positive.

    See also Heartbeats.



722
723
724
725
# File 'proto_docs/google/bigtable/v2/session.rb', line 722

class SessionParametersResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end