Class: Google::Cloud::Bigtable::V2::SessionRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/bigtable/v2/session.rb

Overview

Internal usage only.

Instance Attribute Summary collapse

Instance Attribute Details

#close_session::Google::Cloud::Bigtable::V2::CloseSessionRequest

Returns Note: The following fields are mutually exclusive: close_session, open_session, virtual_rpc. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



309
310
311
312
# File 'proto_docs/google/bigtable/v2/session.rb', line 309

class SessionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#open_session::Google::Cloud::Bigtable::V2::OpenSessionRequest

Returns Note: The following fields are mutually exclusive: open_session, close_session, virtual_rpc. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Bigtable::V2::OpenSessionRequest)

    Note: The following fields are mutually exclusive: open_session, close_session, virtual_rpc. If a field in that set is populated, all other fields in the set will automatically be cleared.



309
310
311
312
# File 'proto_docs/google/bigtable/v2/session.rb', line 309

class SessionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#virtual_rpc::Google::Cloud::Bigtable::V2::VirtualRpcRequest

Returns Note: The following fields are mutually exclusive: virtual_rpc, open_session, close_session. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Bigtable::V2::VirtualRpcRequest)

    Note: The following fields are mutually exclusive: virtual_rpc, open_session, close_session. If a field in that set is populated, all other fields in the set will automatically be cleared.



309
310
311
312
# File 'proto_docs/google/bigtable/v2/session.rb', line 309

class SessionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end