Class: Google::Cloud::Bigtable::V2::TableRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/bigtable/v2/session.rb

Overview

Internal usage only.

Instance Attribute Summary collapse

Instance Attribute Details

#mutate_row::Google::Cloud::Bigtable::V2::SessionMutateRowRequest

Returns Note: The following fields are mutually exclusive: mutate_row, read_row. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



619
620
621
622
# File 'proto_docs/google/bigtable/v2/session.rb', line 619

class TableRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#read_row::Google::Cloud::Bigtable::V2::SessionReadRowRequest

Returns Note: The following fields are mutually exclusive: read_row, mutate_row. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



619
620
621
622
# File 'proto_docs/google/bigtable/v2/session.rb', line 619

class TableRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end