Class: Google::Cloud::Bigtable::V2::ValueBitmask

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/bigtable/v2/data.rb

Overview

Restricts the output to cells whose values match the given bitmask.

Instance Attribute Summary collapse

Instance Attribute Details

#mask::String

Returns Required. Mask applied to the value. Evaluated as: (value & mask) == mask The mask length must exactly match the value length, otherwise the cell is not considered a match.

Returns:

  • (::String)

    Required. Mask applied to the value. Evaluated as: (value & mask) == mask The mask length must exactly match the value length, otherwise the cell is not considered a match.



302
303
304
305
# File 'proto_docs/google/bigtable/v2/data.rb', line 302

class ValueBitmask
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end