Class: Google::Cloud::Bigtable::V2::BackendIdentifier
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::BackendIdentifier
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/session.rb
Overview
Information about the connected backends from a session client's perspective. This information may be used to make choices about session re-establishment en-masse for sessions with the same backend identifiers. Internal usage only.
Instance Attribute Summary collapse
-
#application_frontend_id ⇒ ::Integer
An opaque identifier for the application frontend which serviced this request.
-
#application_frontend_zone ⇒ ::String
The zone of the application frontend that served this request.
-
#google_frontend_id ⇒ ::Integer
An opaque identifier for the Google Frontend which serviced this request.
Instance Attribute Details
#application_frontend_id ⇒ ::Integer
Returns An opaque identifier for the application frontend which serviced this request.
386 387 388 389 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 386 class BackendIdentifier include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#application_frontend_zone ⇒ ::String
Returns The zone of the application frontend that served this request.
386 387 388 389 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 386 class BackendIdentifier include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#google_frontend_id ⇒ ::Integer
Returns An opaque identifier for the Google Frontend which serviced this request. Only set when not using DirectAccess.
386 387 388 389 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 386 class BackendIdentifier include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |