Class: Google::Cloud::Bigtable::V2::Bigtable::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::Bigtable::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/bigtable/v2/bigtable/client.rb
Overview
Client for the Bigtable service.
Service for reading from and writing to existing Bigtable tables.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the Bigtable Client class.
Instance Method Summary collapse
-
#check_and_mutate_row(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Bigtable::V2::CheckAndMutateRowResponse
Mutates a row atomically based on the output of a predicate Reader filter.
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the Bigtable Client instance.
-
#generate_initial_change_stream_partitions(request, options = nil) {|response, operation| ... } ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::GenerateInitialChangeStreamPartitionsResponse>
NOTE: This API is intended to be used by Apache Beam BigtableIO.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new Bigtable client object.
-
#mutate_row(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Bigtable::V2::MutateRowResponse
Mutates a row atomically.
-
#mutate_rows(request, options = nil) {|response, operation| ... } ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::MutateRowsResponse>
Mutates multiple rows in a batch.
-
#ping_and_warm(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Bigtable::V2::PingAndWarmResponse
Warm up associated instance metadata for this connection.
-
#read_change_stream(request, options = nil) {|response, operation| ... } ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ReadChangeStreamResponse>
NOTE: This API is intended to be used by Apache Beam BigtableIO.
-
#read_modify_write_row(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Bigtable::V2::ReadModifyWriteRowResponse
Modifies a row atomically on the server.
-
#read_rows(request, options = nil) {|response, operation| ... } ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ReadRowsResponse>
Streams back the contents of all requested rows in key order, optionally applying the same Reader filter to each.
-
#sample_row_keys(request, options = nil) {|response, operation| ... } ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::SampleRowKeysResponse>
Returns a sample of row keys in the table.
-
#universe_domain ⇒ String
The effective universe domain.
Methods included from Paths
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new Bigtable client object.
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 140 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/bigtable/v2/bigtable_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @bigtable_stub = ::Gapic::ServiceStub.new( ::Google::Cloud::Bigtable::V2::Bigtable::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool ) end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the Bigtable Client class.
See Configuration for a description of the configuration fields.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 59 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Bigtable", "V2"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.read_rows.timeout = 43_200.0 default_config.rpcs.sample_row_keys.timeout = 60.0 default_config.rpcs.mutate_row.timeout = 60.0 default_config.rpcs.mutate_row.retry_policy = { initial_delay: 0.01, max_delay: 60.0, multiplier: 2, retry_codes: [14, 4] } default_config.rpcs.mutate_rows.timeout = 600.0 default_config.rpcs.check_and_mutate_row.timeout = 20.0 default_config.rpcs.read_modify_write_row.timeout = 20.0 default_config.rpcs.generate_initial_change_stream_partitions.timeout = 60.0 default_config.rpcs.read_change_stream.timeout = 43_200.0 default_config end yield @configure if block_given? @configure end |
Instance Method Details
#check_and_mutate_row(request, options = nil) ⇒ ::Google::Cloud::Bigtable::V2::CheckAndMutateRowResponse #check_and_mutate_row(table_name: nil, app_profile_id: nil, row_key: nil, predicate_filter: nil, true_mutations: nil, false_mutations: nil) ⇒ ::Google::Cloud::Bigtable::V2::CheckAndMutateRowResponse
Mutates a row atomically based on the output of a predicate Reader filter.
681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 681 def check_and_mutate_row request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::CheckAndMutateRowRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.check_and_mutate_row..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.table_name && %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/?$}.match?(request.table_name) header_params["table_name"] = request.table_name end if request.app_profile_id && !request.app_profile_id.empty? header_params["app_profile_id"] = request.app_profile_id end request_params_header = URI.encode_www_form header_params [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.check_and_mutate_row.timeout, metadata: , retry_policy: @config.rpcs.check_and_mutate_row.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @bigtable_stub.call_rpc :check_and_mutate_row, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#configure {|config| ... } ⇒ Client::Configuration
Configure the Bigtable Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
110 111 112 113 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 110 def configure yield @config if block_given? @config end |
#generate_initial_change_stream_partitions(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::GenerateInitialChangeStreamPartitionsResponse> #generate_initial_change_stream_partitions(table_name: nil, app_profile_id: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::GenerateInitialChangeStreamPartitionsResponse>
NOTE: This API is intended to be used by Apache Beam BigtableIO.
Returns the current list of partitions that make up the table's
change stream. The union of partitions will cover the entire keyspace.
Partitions can be read with ReadChangeStream.
983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 983 def generate_initial_change_stream_partitions request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::GenerateInitialChangeStreamPartitionsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.generate_initial_change_stream_partitions..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.table_name header_params["table_name"] = request.table_name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.generate_initial_change_stream_partitions.timeout, metadata: , retry_policy: @config.rpcs.generate_initial_change_stream_partitions.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @bigtable_stub.call_rpc :generate_initial_change_stream_partitions, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#mutate_row(request, options = nil) ⇒ ::Google::Cloud::Bigtable::V2::MutateRowResponse #mutate_row(table_name: nil, app_profile_id: nil, row_key: nil, mutations: nil) ⇒ ::Google::Cloud::Bigtable::V2::MutateRowResponse
Mutates a row atomically. Cells already present in the row are left
unchanged unless explicitly changed by mutation.
463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 463 def mutate_row request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::MutateRowRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.mutate_row..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.table_name && %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/?$}.match?(request.table_name) header_params["table_name"] = request.table_name end if request.app_profile_id && !request.app_profile_id.empty? header_params["app_profile_id"] = request.app_profile_id end request_params_header = URI.encode_www_form header_params [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.mutate_row.timeout, metadata: , retry_policy: @config.rpcs.mutate_row.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @bigtable_stub.call_rpc :mutate_row, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#mutate_rows(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::MutateRowsResponse> #mutate_rows(table_name: nil, app_profile_id: nil, entries: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::MutateRowsResponse>
Mutates multiple rows in a batch. Each individual row is mutated atomically as in MutateRow, but the entire batch is not executed atomically.
567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 567 def mutate_rows request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::MutateRowsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.mutate_rows..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.table_name && %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/?$}.match?(request.table_name) header_params["table_name"] = request.table_name end if request.app_profile_id && !request.app_profile_id.empty? header_params["app_profile_id"] = request.app_profile_id end request_params_header = URI.encode_www_form header_params [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.mutate_rows.timeout, metadata: , retry_policy: @config.rpcs.mutate_rows.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @bigtable_stub.call_rpc :mutate_rows, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#ping_and_warm(request, options = nil) ⇒ ::Google::Cloud::Bigtable::V2::PingAndWarmResponse #ping_and_warm(name: nil, app_profile_id: nil) ⇒ ::Google::Cloud::Bigtable::V2::PingAndWarmResponse
Warm up associated instance metadata for this connection. This call is not required but may be useful for connection keep-alive.
776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 776 def ping_and_warm request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::PingAndWarmRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.ping_and_warm..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name && %r{^projects/[^/]+/instances/[^/]+/?$}.match?(request.name) header_params["name"] = request.name end if request.app_profile_id && !request.app_profile_id.empty? header_params["app_profile_id"] = request.app_profile_id end request_params_header = URI.encode_www_form header_params [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.ping_and_warm.timeout, metadata: , retry_policy: @config.rpcs.ping_and_warm.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @bigtable_stub.call_rpc :ping_and_warm, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#read_change_stream(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ReadChangeStreamResponse> #read_change_stream(table_name: nil, app_profile_id: nil, partition: nil, start_time: nil, continuation_tokens: nil, end_time: nil, heartbeat_duration: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ReadChangeStreamResponse>
NOTE: This API is intended to be used by Apache Beam BigtableIO. Reads changes from a table's change stream. Changes will reflect both user-initiated mutations and mutations that are caused by garbage collection.
1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 1106 def read_change_stream request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::ReadChangeStreamRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.read_change_stream..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.table_name header_params["table_name"] = request.table_name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.read_change_stream.timeout, metadata: , retry_policy: @config.rpcs.read_change_stream.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @bigtable_stub.call_rpc :read_change_stream, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#read_modify_write_row(request, options = nil) ⇒ ::Google::Cloud::Bigtable::V2::ReadModifyWriteRowResponse #read_modify_write_row(table_name: nil, app_profile_id: nil, row_key: nil, rules: nil) ⇒ ::Google::Cloud::Bigtable::V2::ReadModifyWriteRowResponse
Modifies a row atomically on the server. The method reads the latest existing timestamp and value from the specified columns and writes a new entry based on pre-defined read/modify/write rules. The new value for the timestamp is the greater of the existing timestamp or the current server time. The method returns the new contents of all modified cells.
881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 881 def read_modify_write_row request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::ReadModifyWriteRowRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.read_modify_write_row..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.table_name && %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/?$}.match?(request.table_name) header_params["table_name"] = request.table_name end if request.app_profile_id && !request.app_profile_id.empty? header_params["app_profile_id"] = request.app_profile_id end request_params_header = URI.encode_www_form header_params [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.read_modify_write_row.timeout, metadata: , retry_policy: @config.rpcs.read_modify_write_row.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @bigtable_stub.call_rpc :read_modify_write_row, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#read_rows(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ReadRowsResponse> #read_rows(table_name: nil, app_profile_id: nil, rows: nil, filter: nil, rows_limit: nil, request_stats_view: nil, reversed: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ReadRowsResponse>
Streams back the contents of all requested rows in key order, optionally applying the same Reader filter to each. Depending on their size, rows and cells may be broken up across multiple responses, but atomicity of each row will still be preserved. See the ReadRowsResponse documentation for details.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 262 def read_rows request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::ReadRowsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.read_rows..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.table_name && %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/?$}.match?(request.table_name) header_params["table_name"] = request.table_name end if request.app_profile_id && !request.app_profile_id.empty? header_params["app_profile_id"] = request.app_profile_id end request_params_header = URI.encode_www_form header_params [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.read_rows.timeout, metadata: , retry_policy: @config.rpcs.read_rows.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @bigtable_stub.call_rpc :read_rows, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#sample_row_keys(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::SampleRowKeysResponse> #sample_row_keys(table_name: nil, app_profile_id: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::SampleRowKeysResponse>
Returns a sample of row keys in the table. The returned row keys will delimit contiguous sections of the table of approximately equal size, which can be used to break up the data for distributed tasks like mapreduces.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 362 def sample_row_keys request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::SampleRowKeysRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.sample_row_keys..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Bigtable::V2::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.table_name && %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/?$}.match?(request.table_name) header_params["table_name"] = request.table_name end if request.app_profile_id && !request.app_profile_id.empty? header_params["app_profile_id"] = request.app_profile_id end request_params_header = URI.encode_www_form header_params [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.sample_row_keys.timeout, metadata: , retry_policy: @config.rpcs.sample_row_keys.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @bigtable_stub.call_rpc :sample_row_keys, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#universe_domain ⇒ String
The effective universe domain
120 121 122 |
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 120 def universe_domain @bigtable_stub.universe_domain end |