Class: Google::Cloud::Bigtable::V2::Bigtable::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/bigtable/v2/bigtable/client.rb

Overview

Client for the Bigtable service.

Service for reading from and writing to existing Bigtable tables.

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#instance_path, #table_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new Bigtable client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Bigtable::V2::Bigtable::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Bigtable::V2::Bigtable::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Bigtable client.

Yield Parameters:



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 140

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/bigtable/v2/bigtable_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @bigtable_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::Bigtable::V2::Bigtable::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool
  )
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the Bigtable Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all Bigtable clients
::Google::Cloud::Bigtable::V2::Bigtable::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 59

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Bigtable", "V2"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.read_rows.timeout = 43_200.0

    default_config.rpcs.sample_row_keys.timeout = 60.0

    default_config.rpcs.mutate_row.timeout = 60.0
    default_config.rpcs.mutate_row.retry_policy = {
      initial_delay: 0.01, max_delay: 60.0, multiplier: 2, retry_codes: [14, 4]
    }

    default_config.rpcs.mutate_rows.timeout = 600.0

    default_config.rpcs.check_and_mutate_row.timeout = 20.0

    default_config.rpcs.read_modify_write_row.timeout = 20.0

    default_config.rpcs.generate_initial_change_stream_partitions.timeout = 60.0

    default_config.rpcs.read_change_stream.timeout = 43_200.0

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#check_and_mutate_row(request, options = nil) ⇒ ::Google::Cloud::Bigtable::V2::CheckAndMutateRowResponse #check_and_mutate_row(table_name: nil, app_profile_id: nil, row_key: nil, predicate_filter: nil, true_mutations: nil, false_mutations: nil) ⇒ ::Google::Cloud::Bigtable::V2::CheckAndMutateRowResponse

Mutates a row atomically based on the output of a predicate Reader filter.

Examples:

Basic example

require "google/cloud/bigtable/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Bigtable::V2::Bigtable::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Bigtable::V2::CheckAndMutateRowRequest.new

# Call the check_and_mutate_row method.
result = client.check_and_mutate_row request

# The returned object is of type Google::Cloud::Bigtable::V2::CheckAndMutateRowResponse.
p result

Overloads:

  • #check_and_mutate_row(request, options = nil) ⇒ ::Google::Cloud::Bigtable::V2::CheckAndMutateRowResponse

    Pass arguments to check_and_mutate_row via a request object, either of type CheckAndMutateRowRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Bigtable::V2::CheckAndMutateRowRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #check_and_mutate_row(table_name: nil, app_profile_id: nil, row_key: nil, predicate_filter: nil, true_mutations: nil, false_mutations: nil) ⇒ ::Google::Cloud::Bigtable::V2::CheckAndMutateRowResponse

    Pass arguments to check_and_mutate_row via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • table_name (::String) (defaults to: nil)

      Required. The unique name of the table to which the conditional mutation should be applied. Values are of the form projects/<project>/instances/<instance>/tables/<table>.

    • app_profile_id (::String) (defaults to: nil)

      This value specifies routing for replication. If not specified, the "default" application profile will be used.

    • row_key (::String) (defaults to: nil)

      Required. The key of the row to which the conditional mutation should be applied.

    • predicate_filter (::Google::Cloud::Bigtable::V2::RowFilter, ::Hash) (defaults to: nil)

      The filter to be applied to the contents of the specified row. Depending on whether or not any results are yielded, either true_mutations or false_mutations will be executed. If unset, checks that the row contains any values at all.

    • true_mutations (::Array<::Google::Cloud::Bigtable::V2::Mutation, ::Hash>) (defaults to: nil)

      Changes to be atomically applied to the specified row if predicate_filter yields at least one cell when applied to row_key. Entries are applied in order, meaning that earlier mutations can be masked by later ones. Must contain at least one entry if false_mutations is empty, and at most 100000.

    • false_mutations (::Array<::Google::Cloud::Bigtable::V2::Mutation, ::Hash>) (defaults to: nil)

      Changes to be atomically applied to the specified row if predicate_filter does not yield any cells when applied to row_key. Entries are applied in order, meaning that earlier mutations can be masked by later ones. Must contain at least one entry if true_mutations is empty, and at most 100000.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 681

def check_and_mutate_row request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::CheckAndMutateRowRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.check_and_mutate_row..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Bigtable::V2::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.table_name &&
     %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/?$}.match?(request.table_name)
    header_params["table_name"] = request.table_name
  end
  if request.app_profile_id && !request.app_profile_id.empty?
    header_params["app_profile_id"] = request.app_profile_id
  end

  request_params_header = URI.encode_www_form header_params
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.check_and_mutate_row.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.check_and_mutate_row.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @bigtable_stub.call_rpc :check_and_mutate_row, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#configure {|config| ... } ⇒ Client::Configuration

Configure the Bigtable Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



110
111
112
113
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 110

def configure
  yield @config if block_given?
  @config
end

#generate_initial_change_stream_partitions(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::GenerateInitialChangeStreamPartitionsResponse> #generate_initial_change_stream_partitions(table_name: nil, app_profile_id: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::GenerateInitialChangeStreamPartitionsResponse>

NOTE: This API is intended to be used by Apache Beam BigtableIO. Returns the current list of partitions that make up the table's change stream. The union of partitions will cover the entire keyspace. Partitions can be read with ReadChangeStream.

Examples:

Basic example

require "google/cloud/bigtable/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Bigtable::V2::Bigtable::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Bigtable::V2::GenerateInitialChangeStreamPartitionsRequest.new

# Call the generate_initial_change_stream_partitions method to start streaming.
output = client.generate_initial_change_stream_partitions request

# The returned object is a streamed enumerable yielding elements of type
# ::Google::Cloud::Bigtable::V2::GenerateInitialChangeStreamPartitionsResponse
output.each do |current_response|
  p current_response
end

Overloads:

  • #generate_initial_change_stream_partitions(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::GenerateInitialChangeStreamPartitionsResponse>

    Pass arguments to generate_initial_change_stream_partitions via a request object, either of type GenerateInitialChangeStreamPartitionsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Bigtable::V2::GenerateInitialChangeStreamPartitionsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #generate_initial_change_stream_partitions(table_name: nil, app_profile_id: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::GenerateInitialChangeStreamPartitionsResponse>

    Pass arguments to generate_initial_change_stream_partitions via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • table_name (::String) (defaults to: nil)

      Required. The unique name of the table from which to get change stream partitions. Values are of the form projects/<project>/instances/<instance>/tables/<table>. Change streaming must be enabled on the table.

    • app_profile_id (::String) (defaults to: nil)

      This value specifies routing for replication. If not specified, the "default" application profile will be used. Single cluster routing must be configured on the profile.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 983

def generate_initial_change_stream_partitions request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::GenerateInitialChangeStreamPartitionsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.generate_initial_change_stream_partitions..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Bigtable::V2::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.table_name
    header_params["table_name"] = request.table_name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.generate_initial_change_stream_partitions.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.generate_initial_change_stream_partitions.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @bigtable_stub.call_rpc :generate_initial_change_stream_partitions, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#mutate_row(request, options = nil) ⇒ ::Google::Cloud::Bigtable::V2::MutateRowResponse #mutate_row(table_name: nil, app_profile_id: nil, row_key: nil, mutations: nil) ⇒ ::Google::Cloud::Bigtable::V2::MutateRowResponse

Mutates a row atomically. Cells already present in the row are left unchanged unless explicitly changed by mutation.

Examples:

Basic example

require "google/cloud/bigtable/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Bigtable::V2::Bigtable::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Bigtable::V2::MutateRowRequest.new

# Call the mutate_row method.
result = client.mutate_row request

# The returned object is of type Google::Cloud::Bigtable::V2::MutateRowResponse.
p result

Overloads:

  • #mutate_row(request, options = nil) ⇒ ::Google::Cloud::Bigtable::V2::MutateRowResponse

    Pass arguments to mutate_row via a request object, either of type MutateRowRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Bigtable::V2::MutateRowRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #mutate_row(table_name: nil, app_profile_id: nil, row_key: nil, mutations: nil) ⇒ ::Google::Cloud::Bigtable::V2::MutateRowResponse

    Pass arguments to mutate_row via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • table_name (::String) (defaults to: nil)

      Required. The unique name of the table to which the mutation should be applied. Values are of the form projects/<project>/instances/<instance>/tables/<table>.

    • app_profile_id (::String) (defaults to: nil)

      This value specifies routing for replication. If not specified, the "default" application profile will be used.

    • row_key (::String) (defaults to: nil)

      Required. The key of the row to which the mutation should be applied.

    • mutations (::Array<::Google::Cloud::Bigtable::V2::Mutation, ::Hash>) (defaults to: nil)

      Required. Changes to be atomically applied to the specified row. Entries are applied in order, meaning that earlier mutations can be masked by later ones. Must contain at least one entry and at most 100000.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 463

def mutate_row request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::MutateRowRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.mutate_row..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Bigtable::V2::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.table_name &&
     %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/?$}.match?(request.table_name)
    header_params["table_name"] = request.table_name
  end
  if request.app_profile_id && !request.app_profile_id.empty?
    header_params["app_profile_id"] = request.app_profile_id
  end

  request_params_header = URI.encode_www_form header_params
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.mutate_row.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.mutate_row.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @bigtable_stub.call_rpc :mutate_row, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#mutate_rows(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::MutateRowsResponse> #mutate_rows(table_name: nil, app_profile_id: nil, entries: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::MutateRowsResponse>

Mutates multiple rows in a batch. Each individual row is mutated atomically as in MutateRow, but the entire batch is not executed atomically.

Examples:

Basic example

require "google/cloud/bigtable/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Bigtable::V2::Bigtable::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Bigtable::V2::MutateRowsRequest.new

# Call the mutate_rows method to start streaming.
output = client.mutate_rows request

# The returned object is a streamed enumerable yielding elements of type
# ::Google::Cloud::Bigtable::V2::MutateRowsResponse
output.each do |current_response|
  p current_response
end

Overloads:

  • #mutate_rows(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::MutateRowsResponse>

    Pass arguments to mutate_rows via a request object, either of type MutateRowsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Bigtable::V2::MutateRowsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #mutate_rows(table_name: nil, app_profile_id: nil, entries: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::MutateRowsResponse>

    Pass arguments to mutate_rows via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • table_name (::String) (defaults to: nil)

      Required. The unique name of the table to which the mutations should be applied.

    • app_profile_id (::String) (defaults to: nil)

      This value specifies routing for replication. If not specified, the "default" application profile will be used.

    • entries (::Array<::Google::Cloud::Bigtable::V2::MutateRowsRequest::Entry, ::Hash>) (defaults to: nil)

      Required. The row keys and corresponding mutations to be applied in bulk. Each entry is applied as an atomic mutation, but the entries may be applied in arbitrary order (even between entries for the same row). At least one entry must be specified, and in total the entries can contain at most 100000 mutations.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 567

def mutate_rows request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::MutateRowsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.mutate_rows..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Bigtable::V2::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.table_name &&
     %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/?$}.match?(request.table_name)
    header_params["table_name"] = request.table_name
  end
  if request.app_profile_id && !request.app_profile_id.empty?
    header_params["app_profile_id"] = request.app_profile_id
  end

  request_params_header = URI.encode_www_form header_params
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.mutate_rows.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.mutate_rows.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @bigtable_stub.call_rpc :mutate_rows, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#ping_and_warm(request, options = nil) ⇒ ::Google::Cloud::Bigtable::V2::PingAndWarmResponse #ping_and_warm(name: nil, app_profile_id: nil) ⇒ ::Google::Cloud::Bigtable::V2::PingAndWarmResponse

Warm up associated instance metadata for this connection. This call is not required but may be useful for connection keep-alive.

Examples:

Basic example

require "google/cloud/bigtable/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Bigtable::V2::Bigtable::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Bigtable::V2::PingAndWarmRequest.new

# Call the ping_and_warm method.
result = client.ping_and_warm request

# The returned object is of type Google::Cloud::Bigtable::V2::PingAndWarmResponse.
p result

Overloads:

  • #ping_and_warm(request, options = nil) ⇒ ::Google::Cloud::Bigtable::V2::PingAndWarmResponse

    Pass arguments to ping_and_warm via a request object, either of type PingAndWarmRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Bigtable::V2::PingAndWarmRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #ping_and_warm(name: nil, app_profile_id: nil) ⇒ ::Google::Cloud::Bigtable::V2::PingAndWarmResponse

    Pass arguments to ping_and_warm via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The unique name of the instance to check permissions for as well as respond. Values are of the form projects/<project>/instances/<instance>.

    • app_profile_id (::String) (defaults to: nil)

      This value specifies routing for replication. If not specified, the "default" application profile will be used.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 776

def ping_and_warm request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::PingAndWarmRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.ping_and_warm..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Bigtable::V2::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name &&
     %r{^projects/[^/]+/instances/[^/]+/?$}.match?(request.name)
    header_params["name"] = request.name
  end
  if request.app_profile_id && !request.app_profile_id.empty?
    header_params["app_profile_id"] = request.app_profile_id
  end

  request_params_header = URI.encode_www_form header_params
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.ping_and_warm.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.ping_and_warm.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @bigtable_stub.call_rpc :ping_and_warm, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#read_change_stream(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ReadChangeStreamResponse> #read_change_stream(table_name: nil, app_profile_id: nil, partition: nil, start_time: nil, continuation_tokens: nil, end_time: nil, heartbeat_duration: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ReadChangeStreamResponse>

NOTE: This API is intended to be used by Apache Beam BigtableIO. Reads changes from a table's change stream. Changes will reflect both user-initiated mutations and mutations that are caused by garbage collection.

Examples:

Basic example

require "google/cloud/bigtable/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Bigtable::V2::Bigtable::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Bigtable::V2::ReadChangeStreamRequest.new

# Call the read_change_stream method to start streaming.
output = client.read_change_stream request

# The returned object is a streamed enumerable yielding elements of type
# ::Google::Cloud::Bigtable::V2::ReadChangeStreamResponse
output.each do |current_response|
  p current_response
end

Overloads:

  • #read_change_stream(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ReadChangeStreamResponse>

    Pass arguments to read_change_stream via a request object, either of type ReadChangeStreamRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Bigtable::V2::ReadChangeStreamRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #read_change_stream(table_name: nil, app_profile_id: nil, partition: nil, start_time: nil, continuation_tokens: nil, end_time: nil, heartbeat_duration: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ReadChangeStreamResponse>

    Pass arguments to read_change_stream via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • table_name (::String) (defaults to: nil)

      Required. The unique name of the table from which to read a change stream. Values are of the form projects/<project>/instances/<instance>/tables/<table>. Change streaming must be enabled on the table.

    • app_profile_id (::String) (defaults to: nil)

      This value specifies routing for replication. If not specified, the "default" application profile will be used. Single cluster routing must be configured on the profile.

    • partition (::Google::Cloud::Bigtable::V2::StreamPartition, ::Hash) (defaults to: nil)

      The partition to read changes from.

    • start_time (::Google::Protobuf::Timestamp, ::Hash) (defaults to: nil)

      Start reading the stream at the specified timestamp. This timestamp must be within the change stream retention period, less than or equal to the current time, and after change stream creation, whichever is greater. This value is inclusive and will be truncated to microsecond granularity.

    • continuation_tokens (::Google::Cloud::Bigtable::V2::StreamContinuationTokens, ::Hash) (defaults to: nil)

      Tokens that describe how to resume reading a stream where reading previously left off. If specified, changes will be read starting at the the position. Tokens are delivered on the stream as part of Heartbeat and CloseStream messages.

      If a single token is provided, the token’s partition must exactly match the request’s partition. If multiple tokens are provided, as in the case of a partition merge, the union of the token partitions must exactly cover the request’s partition. Otherwise, INVALID_ARGUMENT will be returned.

    • end_time (::Google::Protobuf::Timestamp, ::Hash) (defaults to: nil)

      If specified, OK will be returned when the stream advances beyond this time. Otherwise, changes will be continuously delivered on the stream. This value is inclusive and will be truncated to microsecond granularity.

    • heartbeat_duration (::Google::Protobuf::Duration, ::Hash) (defaults to: nil)

      If specified, the duration between Heartbeat messages on the stream. Otherwise, defaults to 5 seconds.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 1106

def read_change_stream request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::ReadChangeStreamRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.read_change_stream..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Bigtable::V2::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.table_name
    header_params["table_name"] = request.table_name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.read_change_stream.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.read_change_stream.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @bigtable_stub.call_rpc :read_change_stream, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#read_modify_write_row(request, options = nil) ⇒ ::Google::Cloud::Bigtable::V2::ReadModifyWriteRowResponse #read_modify_write_row(table_name: nil, app_profile_id: nil, row_key: nil, rules: nil) ⇒ ::Google::Cloud::Bigtable::V2::ReadModifyWriteRowResponse

Modifies a row atomically on the server. The method reads the latest existing timestamp and value from the specified columns and writes a new entry based on pre-defined read/modify/write rules. The new value for the timestamp is the greater of the existing timestamp or the current server time. The method returns the new contents of all modified cells.

Examples:

Basic example

require "google/cloud/bigtable/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Bigtable::V2::Bigtable::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Bigtable::V2::ReadModifyWriteRowRequest.new

# Call the read_modify_write_row method.
result = client.read_modify_write_row request

# The returned object is of type Google::Cloud::Bigtable::V2::ReadModifyWriteRowResponse.
p result

Overloads:

  • #read_modify_write_row(request, options = nil) ⇒ ::Google::Cloud::Bigtable::V2::ReadModifyWriteRowResponse

    Pass arguments to read_modify_write_row via a request object, either of type ReadModifyWriteRowRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Bigtable::V2::ReadModifyWriteRowRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #read_modify_write_row(table_name: nil, app_profile_id: nil, row_key: nil, rules: nil) ⇒ ::Google::Cloud::Bigtable::V2::ReadModifyWriteRowResponse

    Pass arguments to read_modify_write_row via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • table_name (::String) (defaults to: nil)

      Required. The unique name of the table to which the read/modify/write rules should be applied. Values are of the form projects/<project>/instances/<instance>/tables/<table>.

    • app_profile_id (::String) (defaults to: nil)

      This value specifies routing for replication. If not specified, the "default" application profile will be used.

    • row_key (::String) (defaults to: nil)

      Required. The key of the row to which the read/modify/write rules should be applied.

    • rules (::Array<::Google::Cloud::Bigtable::V2::ReadModifyWriteRule, ::Hash>) (defaults to: nil)

      Required. Rules specifying how the specified row's contents are to be transformed into writes. Entries are applied in order, meaning that earlier rules will affect the results of later ones.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 881

def read_modify_write_row request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::ReadModifyWriteRowRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.read_modify_write_row..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Bigtable::V2::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.table_name &&
     %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/?$}.match?(request.table_name)
    header_params["table_name"] = request.table_name
  end
  if request.app_profile_id && !request.app_profile_id.empty?
    header_params["app_profile_id"] = request.app_profile_id
  end

  request_params_header = URI.encode_www_form header_params
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.read_modify_write_row.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.read_modify_write_row.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @bigtable_stub.call_rpc :read_modify_write_row, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#read_rows(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ReadRowsResponse> #read_rows(table_name: nil, app_profile_id: nil, rows: nil, filter: nil, rows_limit: nil, request_stats_view: nil, reversed: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ReadRowsResponse>

Streams back the contents of all requested rows in key order, optionally applying the same Reader filter to each. Depending on their size, rows and cells may be broken up across multiple responses, but atomicity of each row will still be preserved. See the ReadRowsResponse documentation for details.

Examples:

Basic example

require "google/cloud/bigtable/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Bigtable::V2::Bigtable::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Bigtable::V2::ReadRowsRequest.new

# Call the read_rows method to start streaming.
output = client.read_rows request

# The returned object is a streamed enumerable yielding elements of type
# ::Google::Cloud::Bigtable::V2::ReadRowsResponse
output.each do |current_response|
  p current_response
end

Overloads:

  • #read_rows(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ReadRowsResponse>

    Pass arguments to read_rows via a request object, either of type ReadRowsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Bigtable::V2::ReadRowsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #read_rows(table_name: nil, app_profile_id: nil, rows: nil, filter: nil, rows_limit: nil, request_stats_view: nil, reversed: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ReadRowsResponse>

    Pass arguments to read_rows via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • table_name (::String) (defaults to: nil)

      Required. The unique name of the table from which to read. Values are of the form projects/<project>/instances/<instance>/tables/<table>.

    • app_profile_id (::String) (defaults to: nil)

      This value specifies routing for replication. If not specified, the "default" application profile will be used.

    • rows (::Google::Cloud::Bigtable::V2::RowSet, ::Hash) (defaults to: nil)

      The row keys and/or ranges to read sequentially. If not specified, reads from all rows.

    • filter (::Google::Cloud::Bigtable::V2::RowFilter, ::Hash) (defaults to: nil)

      The filter to apply to the contents of the specified row(s). If unset, reads the entirety of each row.

    • rows_limit (::Integer) (defaults to: nil)

      The read will stop after committing to N rows' worth of results. The default (zero) is to return all results.

    • request_stats_view (::Google::Cloud::Bigtable::V2::ReadRowsRequest::RequestStatsView) (defaults to: nil)

      The view into RequestStats, as described above.

    • reversed (::Boolean) (defaults to: nil)

      Experimental API - Please note that this API is currently experimental and can change in the future.

      Return rows in lexiographical descending order of the row keys. The row contents will not be affected by this flag.

      Example result set:

      [
        {key: "k2", "f:col1": "v1", "f:col2": "v1"},
        {key: "k1", "f:col1": "v2", "f:col2": "v2"}
      ]
      

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 262

def read_rows request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::ReadRowsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.read_rows..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Bigtable::V2::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.table_name &&
     %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/?$}.match?(request.table_name)
    header_params["table_name"] = request.table_name
  end
  if request.app_profile_id && !request.app_profile_id.empty?
    header_params["app_profile_id"] = request.app_profile_id
  end

  request_params_header = URI.encode_www_form header_params
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.read_rows.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.read_rows.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @bigtable_stub.call_rpc :read_rows, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#sample_row_keys(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::SampleRowKeysResponse> #sample_row_keys(table_name: nil, app_profile_id: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::SampleRowKeysResponse>

Returns a sample of row keys in the table. The returned row keys will delimit contiguous sections of the table of approximately equal size, which can be used to break up the data for distributed tasks like mapreduces.

Examples:

Basic example

require "google/cloud/bigtable/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Bigtable::V2::Bigtable::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Bigtable::V2::SampleRowKeysRequest.new

# Call the sample_row_keys method to start streaming.
output = client.sample_row_keys request

# The returned object is a streamed enumerable yielding elements of type
# ::Google::Cloud::Bigtable::V2::SampleRowKeysResponse
output.each do |current_response|
  p current_response
end

Overloads:

  • #sample_row_keys(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::SampleRowKeysResponse>

    Pass arguments to sample_row_keys via a request object, either of type SampleRowKeysRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Bigtable::V2::SampleRowKeysRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #sample_row_keys(table_name: nil, app_profile_id: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::SampleRowKeysResponse>

    Pass arguments to sample_row_keys via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • table_name (::String) (defaults to: nil)

      Required. The unique name of the table from which to sample row keys. Values are of the form projects/<project>/instances/<instance>/tables/<table>.

    • app_profile_id (::String) (defaults to: nil)

      This value specifies routing for replication. If not specified, the "default" application profile will be used.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 362

def sample_row_keys request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::SampleRowKeysRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.sample_row_keys..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Bigtable::V2::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.table_name &&
     %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/?$}.match?(request.table_name)
    header_params["table_name"] = request.table_name
  end
  if request.app_profile_id && !request.app_profile_id.empty?
    header_params["app_profile_id"] = request.app_profile_id
  end

  request_params_header = URI.encode_www_form header_params
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.sample_row_keys.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.sample_row_keys.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @bigtable_stub.call_rpc :sample_row_keys, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


120
121
122
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 120

def universe_domain
  @bigtable_stub.universe_domain
end