Class: Google::Cloud::Bigtable::V2::Bigtable::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/bigtable/v2/bigtable/client.rb

Overview

Client for the Bigtable service.

Service for reading from and writing to existing Bigtable tables.

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#instance_path, #table_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new Bigtable client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Bigtable::V2::Bigtable::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Bigtable::V2::Bigtable::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Bigtable client.

Yield Parameters:



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 124

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/bigtable/v2/bigtable_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint == Client.configure.endpoint &&
                           !@config.endpoint.split(".").first.include?("-")
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @bigtable_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::Bigtable::V2::Bigtable::Stub,
    credentials:  credentials,
    endpoint:     @config.endpoint,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors
  )
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the Bigtable Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all Bigtable clients
::Google::Cloud::Bigtable::V2::Bigtable::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 56

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Bigtable", "V2"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.read_rows.timeout = 43_200.0

    default_config.rpcs.sample_row_keys.timeout = 60.0

    default_config.rpcs.mutate_row.timeout = 60.0
    default_config.rpcs.mutate_row.retry_policy = {
      initial_delay: 0.01, max_delay: 60.0, multiplier: 2, retry_codes: [14, 4]
    }

    default_config.rpcs.mutate_rows.timeout = 600.0

    default_config.rpcs.check_and_mutate_row.timeout = 20.0

    default_config.rpcs.read_modify_write_row.timeout = 20.0

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#check_and_mutate_row(request, options = nil) ⇒ ::Google::Cloud::Bigtable::V2::CheckAndMutateRowResponse #check_and_mutate_row(table_name: nil, app_profile_id: nil, row_key: nil, predicate_filter: nil, true_mutations: nil, false_mutations: nil) ⇒ ::Google::Cloud::Bigtable::V2::CheckAndMutateRowResponse

Mutates a row atomically based on the output of a predicate Reader filter.

Examples:

Basic example

require "google/cloud/bigtable/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Bigtable::V2::Bigtable::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Bigtable::V2::CheckAndMutateRowRequest.new

# Call the check_and_mutate_row method.
result = client.check_and_mutate_row request

# The returned object is of type Google::Cloud::Bigtable::V2::CheckAndMutateRowResponse.
p result

Overloads:

  • #check_and_mutate_row(request, options = nil) ⇒ ::Google::Cloud::Bigtable::V2::CheckAndMutateRowResponse

    Pass arguments to check_and_mutate_row via a request object, either of type CheckAndMutateRowRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Bigtable::V2::CheckAndMutateRowRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #check_and_mutate_row(table_name: nil, app_profile_id: nil, row_key: nil, predicate_filter: nil, true_mutations: nil, false_mutations: nil) ⇒ ::Google::Cloud::Bigtable::V2::CheckAndMutateRowResponse

    Pass arguments to check_and_mutate_row via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • table_name (::String) (defaults to: nil)

      Required. The unique name of the table to which the conditional mutation should be applied. Values are of the form projects/<project>/instances/<instance>/tables/<table>.

    • app_profile_id (::String) (defaults to: nil)

      This value specifies routing for replication. If not specified, the "default" application profile will be used.

    • row_key (::String) (defaults to: nil)

      Required. The key of the row to which the conditional mutation should be applied.

    • predicate_filter (::Google::Cloud::Bigtable::V2::RowFilter, ::Hash) (defaults to: nil)

      The filter to be applied to the contents of the specified row. Depending on whether or not any results are yielded, either true_mutations or false_mutations will be executed. If unset, checks that the row contains any values at all.

    • true_mutations (::Array<::Google::Cloud::Bigtable::V2::Mutation, ::Hash>) (defaults to: nil)

      Changes to be atomically applied to the specified row if predicate_filter yields at least one cell when applied to row_key. Entries are applied in order, meaning that earlier mutations can be masked by later ones. Must contain at least one entry if false_mutations is empty, and at most 100000.

    • false_mutations (::Array<::Google::Cloud::Bigtable::V2::Mutation, ::Hash>) (defaults to: nil)

      Changes to be atomically applied to the specified row if predicate_filter does not yield any cells when applied to row_key. Entries are applied in order, meaning that earlier mutations can be masked by later ones. Must contain at least one entry if true_mutations is empty, and at most 100000.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 647

def check_and_mutate_row request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::CheckAndMutateRowRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.check_and_mutate_row..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Bigtable::V2::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.table_name &&
     %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/?$}.match?(request.table_name)
    header_params["table_name"] = request.table_name
  end
  if request.app_profile_id && !request.app_profile_id.empty?
    header_params["app_profile_id"] = request.app_profile_id
  end

  request_params_header = URI.encode_www_form header_params
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.check_and_mutate_row.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.check_and_mutate_row.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @bigtable_stub.call_rpc :check_and_mutate_row, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#configure {|config| ... } ⇒ Client::Configuration

Configure the Bigtable Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



103
104
105
106
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 103

def configure
  yield @config if block_given?
  @config
end

#mutate_row(request, options = nil) ⇒ ::Google::Cloud::Bigtable::V2::MutateRowResponse #mutate_row(table_name: nil, app_profile_id: nil, row_key: nil, mutations: nil) ⇒ ::Google::Cloud::Bigtable::V2::MutateRowResponse

Mutates a row atomically. Cells already present in the row are left unchanged unless explicitly changed by mutation.

Examples:

Basic example

require "google/cloud/bigtable/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Bigtable::V2::Bigtable::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Bigtable::V2::MutateRowRequest.new

# Call the mutate_row method.
result = client.mutate_row request

# The returned object is of type Google::Cloud::Bigtable::V2::MutateRowResponse.
p result

Overloads:

  • #mutate_row(request, options = nil) ⇒ ::Google::Cloud::Bigtable::V2::MutateRowResponse

    Pass arguments to mutate_row via a request object, either of type MutateRowRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Bigtable::V2::MutateRowRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #mutate_row(table_name: nil, app_profile_id: nil, row_key: nil, mutations: nil) ⇒ ::Google::Cloud::Bigtable::V2::MutateRowResponse

    Pass arguments to mutate_row via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • table_name (::String) (defaults to: nil)

      Required. The unique name of the table to which the mutation should be applied. Values are of the form projects/<project>/instances/<instance>/tables/<table>.

    • app_profile_id (::String) (defaults to: nil)

      This value specifies routing for replication. If not specified, the "default" application profile will be used.

    • row_key (::String) (defaults to: nil)

      Required. The key of the row to which the mutation should be applied.

    • mutations (::Array<::Google::Cloud::Bigtable::V2::Mutation, ::Hash>) (defaults to: nil)

      Required. Changes to be atomically applied to the specified row. Entries are applied in order, meaning that earlier mutations can be masked by later ones. Must contain at least one entry and at most 100000.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 430

def mutate_row request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::MutateRowRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.mutate_row..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Bigtable::V2::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.table_name &&
     %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/?$}.match?(request.table_name)
    header_params["table_name"] = request.table_name
  end
  if request.app_profile_id && !request.app_profile_id.empty?
    header_params["app_profile_id"] = request.app_profile_id
  end

  request_params_header = URI.encode_www_form header_params
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.mutate_row.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.mutate_row.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @bigtable_stub.call_rpc :mutate_row, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#mutate_rows(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::MutateRowsResponse> #mutate_rows(table_name: nil, app_profile_id: nil, entries: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::MutateRowsResponse>

Mutates multiple rows in a batch. Each individual row is mutated atomically as in MutateRow, but the entire batch is not executed atomically.

Examples:

Basic example

require "google/cloud/bigtable/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Bigtable::V2::Bigtable::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Bigtable::V2::MutateRowsRequest.new

# Call the mutate_rows method.
result = client.mutate_rows request

# The returned object is a streamed enumerable yielding elements of
# type ::Google::Cloud::Bigtable::V2::MutateRowsResponse.
result.each do |response|
  p response
end

Overloads:

  • #mutate_rows(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::MutateRowsResponse>

    Pass arguments to mutate_rows via a request object, either of type MutateRowsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Bigtable::V2::MutateRowsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #mutate_rows(table_name: nil, app_profile_id: nil, entries: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::MutateRowsResponse>

    Pass arguments to mutate_rows via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • table_name (::String) (defaults to: nil)

      Required. The unique name of the table to which the mutations should be applied.

    • app_profile_id (::String) (defaults to: nil)

      This value specifies routing for replication. If not specified, the "default" application profile will be used.

    • entries (::Array<::Google::Cloud::Bigtable::V2::MutateRowsRequest::Entry, ::Hash>) (defaults to: nil)

      Required. The row keys and corresponding mutations to be applied in bulk. Each entry is applied as an atomic mutation, but the entries may be applied in arbitrary order (even between entries for the same row). At least one entry must be specified, and in total the entries can contain at most 100000 mutations.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 533

def mutate_rows request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::MutateRowsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.mutate_rows..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Bigtable::V2::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.table_name &&
     %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/?$}.match?(request.table_name)
    header_params["table_name"] = request.table_name
  end
  if request.app_profile_id && !request.app_profile_id.empty?
    header_params["app_profile_id"] = request.app_profile_id
  end

  request_params_header = URI.encode_www_form header_params
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.mutate_rows.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.mutate_rows.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @bigtable_stub.call_rpc :mutate_rows, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#ping_and_warm(request, options = nil) ⇒ ::Google::Cloud::Bigtable::V2::PingAndWarmResponse #ping_and_warm(name: nil, app_profile_id: nil) ⇒ ::Google::Cloud::Bigtable::V2::PingAndWarmResponse

Warm up associated instance metadata for this connection. This call is not required but may be useful for connection keep-alive.

Examples:

Basic example

require "google/cloud/bigtable/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Bigtable::V2::Bigtable::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Bigtable::V2::PingAndWarmRequest.new

# Call the ping_and_warm method.
result = client.ping_and_warm request

# The returned object is of type Google::Cloud::Bigtable::V2::PingAndWarmResponse.
p result

Overloads:

  • #ping_and_warm(request, options = nil) ⇒ ::Google::Cloud::Bigtable::V2::PingAndWarmResponse

    Pass arguments to ping_and_warm via a request object, either of type PingAndWarmRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Bigtable::V2::PingAndWarmRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #ping_and_warm(name: nil, app_profile_id: nil) ⇒ ::Google::Cloud::Bigtable::V2::PingAndWarmResponse

    Pass arguments to ping_and_warm via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The unique name of the instance to check permissions for as well as respond. Values are of the form projects/<project>/instances/<instance>.

    • app_profile_id (::String) (defaults to: nil)

      This value specifies routing for replication. If not specified, the "default" application profile will be used.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 741

def ping_and_warm request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::PingAndWarmRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.ping_and_warm..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Bigtable::V2::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name &&
     %r{^projects/[^/]+/instances/[^/]+/?$}.match?(request.name)
    header_params["name"] = request.name
  end
  if request.app_profile_id && !request.app_profile_id.empty?
    header_params["app_profile_id"] = request.app_profile_id
  end

  request_params_header = URI.encode_www_form header_params
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.ping_and_warm.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.ping_and_warm.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @bigtable_stub.call_rpc :ping_and_warm, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#read_modify_write_row(request, options = nil) ⇒ ::Google::Cloud::Bigtable::V2::ReadModifyWriteRowResponse #read_modify_write_row(table_name: nil, app_profile_id: nil, row_key: nil, rules: nil) ⇒ ::Google::Cloud::Bigtable::V2::ReadModifyWriteRowResponse

Modifies a row atomically on the server. The method reads the latest existing timestamp and value from the specified columns and writes a new entry based on pre-defined read/modify/write rules. The new value for the timestamp is the greater of the existing timestamp or the current server time. The method returns the new contents of all modified cells.

Examples:

Basic example

require "google/cloud/bigtable/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Bigtable::V2::Bigtable::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Bigtable::V2::ReadModifyWriteRowRequest.new

# Call the read_modify_write_row method.
result = client.read_modify_write_row request

# The returned object is of type Google::Cloud::Bigtable::V2::ReadModifyWriteRowResponse.
p result

Overloads:

  • #read_modify_write_row(request, options = nil) ⇒ ::Google::Cloud::Bigtable::V2::ReadModifyWriteRowResponse

    Pass arguments to read_modify_write_row via a request object, either of type ReadModifyWriteRowRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Bigtable::V2::ReadModifyWriteRowRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #read_modify_write_row(table_name: nil, app_profile_id: nil, row_key: nil, rules: nil) ⇒ ::Google::Cloud::Bigtable::V2::ReadModifyWriteRowResponse

    Pass arguments to read_modify_write_row via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • table_name (::String) (defaults to: nil)

      Required. The unique name of the table to which the read/modify/write rules should be applied. Values are of the form projects/<project>/instances/<instance>/tables/<table>.

    • app_profile_id (::String) (defaults to: nil)

      This value specifies routing for replication. If not specified, the "default" application profile will be used.

    • row_key (::String) (defaults to: nil)

      Required. The key of the row to which the read/modify/write rules should be applied.

    • rules (::Array<::Google::Cloud::Bigtable::V2::ReadModifyWriteRule, ::Hash>) (defaults to: nil)

      Required. Rules specifying how the specified row's contents are to be transformed into writes. Entries are applied in order, meaning that earlier rules will affect the results of later ones.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 846

def read_modify_write_row request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::ReadModifyWriteRowRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.read_modify_write_row..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Bigtable::V2::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.table_name &&
     %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/?$}.match?(request.table_name)
    header_params["table_name"] = request.table_name
  end
  if request.app_profile_id && !request.app_profile_id.empty?
    header_params["app_profile_id"] = request.app_profile_id
  end

  request_params_header = URI.encode_www_form header_params
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.read_modify_write_row.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.read_modify_write_row.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @bigtable_stub.call_rpc :read_modify_write_row, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#read_rows(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ReadRowsResponse> #read_rows(table_name: nil, app_profile_id: nil, rows: nil, filter: nil, rows_limit: nil, request_stats_view: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ReadRowsResponse>

Streams back the contents of all requested rows in key order, optionally applying the same Reader filter to each. Depending on their size, rows and cells may be broken up across multiple responses, but atomicity of each row will still be preserved. See the ReadRowsResponse documentation for details.

Examples:

Basic example

require "google/cloud/bigtable/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Bigtable::V2::Bigtable::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Bigtable::V2::ReadRowsRequest.new

# Call the read_rows method.
result = client.read_rows request

# The returned object is a streamed enumerable yielding elements of
# type ::Google::Cloud::Bigtable::V2::ReadRowsResponse.
result.each do |response|
  p response
end

Overloads:

  • #read_rows(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ReadRowsResponse>

    Pass arguments to read_rows via a request object, either of type ReadRowsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Bigtable::V2::ReadRowsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #read_rows(table_name: nil, app_profile_id: nil, rows: nil, filter: nil, rows_limit: nil, request_stats_view: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::ReadRowsResponse>

    Pass arguments to read_rows via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • table_name (::String) (defaults to: nil)

      Required. The unique name of the table from which to read. Values are of the form projects/<project>/instances/<instance>/tables/<table>.

    • app_profile_id (::String) (defaults to: nil)

      This value specifies routing for replication. This API only accepts the empty value of app_profile_id.

    • rows (::Google::Cloud::Bigtable::V2::RowSet, ::Hash) (defaults to: nil)

      The row keys and/or ranges to read sequentially. If not specified, reads from all rows.

    • filter (::Google::Cloud::Bigtable::V2::RowFilter, ::Hash) (defaults to: nil)

      The filter to apply to the contents of the specified row(s). If unset, reads the entirety of each row.

    • rows_limit (::Integer) (defaults to: nil)

      The read will stop after committing to N rows' worth of results. The default (zero) is to return all results.

    • request_stats_view (::Google::Cloud::Bigtable::V2::ReadRowsRequest::RequestStatsView) (defaults to: nil)

      The view into RequestStats, as described above.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 229

def read_rows request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::ReadRowsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.read_rows..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Bigtable::V2::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.table_name &&
     %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/?$}.match?(request.table_name)
    header_params["table_name"] = request.table_name
  end
  if request.app_profile_id && !request.app_profile_id.empty?
    header_params["app_profile_id"] = request.app_profile_id
  end

  request_params_header = URI.encode_www_form header_params
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.read_rows.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.read_rows.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @bigtable_stub.call_rpc :read_rows, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#sample_row_keys(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::SampleRowKeysResponse> #sample_row_keys(table_name: nil, app_profile_id: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::SampleRowKeysResponse>

Returns a sample of row keys in the table. The returned row keys will delimit contiguous sections of the table of approximately equal size, which can be used to break up the data for distributed tasks like mapreduces.

Examples:

Basic example

require "google/cloud/bigtable/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Bigtable::V2::Bigtable::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Bigtable::V2::SampleRowKeysRequest.new

# Call the sample_row_keys method.
result = client.sample_row_keys request

# The returned object is a streamed enumerable yielding elements of
# type ::Google::Cloud::Bigtable::V2::SampleRowKeysResponse.
result.each do |response|
  p response
end

Overloads:

  • #sample_row_keys(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::SampleRowKeysResponse>

    Pass arguments to sample_row_keys via a request object, either of type SampleRowKeysRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Bigtable::V2::SampleRowKeysRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #sample_row_keys(table_name: nil, app_profile_id: nil) ⇒ ::Enumerable<::Google::Cloud::Bigtable::V2::SampleRowKeysResponse>

    Pass arguments to sample_row_keys via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • table_name (::String) (defaults to: nil)

      Required. The unique name of the table from which to sample row keys. Values are of the form projects/<project>/instances/<instance>/tables/<table>.

    • app_profile_id (::String) (defaults to: nil)

      This value specifies routing for replication. If not specified, the "default" application profile will be used.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
# File 'lib/google/cloud/bigtable/v2/bigtable/client.rb', line 329

def sample_row_keys request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Bigtable::V2::SampleRowKeysRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.sample_row_keys..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Bigtable::V2::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.table_name &&
     %r{^projects/[^/]+/instances/[^/]+/tables/[^/]+/?$}.match?(request.table_name)
    header_params["table_name"] = request.table_name
  end
  if request.app_profile_id && !request.app_profile_id.empty?
    header_params["app_profile_id"] = request.app_profile_id
  end

  request_params_header = URI.encode_www_form header_params
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.sample_row_keys.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.sample_row_keys.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @bigtable_stub.call_rpc :sample_row_keys, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end