Class: Google::Cloud::Bigtable::V2::ClientConfiguration
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::ClientConfiguration
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/session.rb
Overview
Configuration for the Session API. Internal usage only.
Defined Under Namespace
Classes: PollingConfiguration
Instance Attribute Summary collapse
-
#polling_configuration ⇒ ::Google::Cloud::Bigtable::V2::ClientConfiguration::PollingConfiguration
If the client should continue to check for new configurations.
-
#polling_interval ⇒ ::Google::Protobuf::Duration
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#session_configuration ⇒ ::Google::Cloud::Bigtable::V2::SessionClientConfiguration
The configuration for Bigtable Sessions.
-
#stop_polling ⇒ ::Boolean
If the client should cease to check for new configurations, e.g.
-
#telemetry_configuration ⇒ ::Google::Cloud::Bigtable::V2::TelemetryConfiguration
Configuration for telemetry.
Instance Attribute Details
#polling_configuration ⇒ ::Google::Cloud::Bigtable::V2::ClientConfiguration::PollingConfiguration
Returns If the client should continue to check for new configurations.
Note: The following fields are mutually exclusive: polling_configuration, stop_polling, polling_interval. If a field in that set is populated, all other fields in the set will automatically be cleared.
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 272 class ClientConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] polling_interval # @return [::Google::Protobuf::Duration] # A duration describing the time between GetClientConfiguration RPCs. # Only strictly positive values are permissible. # @!attribute [rw] validity_duration # @return [::Google::Protobuf::Duration] # How long the client should consider the configuration it receives from # GetClientConfiguration valid for. Once this duration has passed, the # client should consider the configuration invalid and must either: # - Get a new configuration from GetClientConfiguration # - Or if it cannot, use a sane default configuration # # This duration will be at least as long as the polling interval. # @!attribute [rw] max_rpc_retry_count # @return [::Integer] # Number of times the client should retry a failed # GetClientConfiguration RPC per polling interval before giving up. class PollingConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#polling_interval ⇒ ::Google::Protobuf::Duration
This field is deprecated and may be removed in the next major version update.
Returns Deprecated, prerfer polling_configuration.
A duration describing the time between GetClientConfiguration RPCs. Only strictly positive values are permissible.
Note: The following fields are mutually exclusive: polling_interval, stop_polling, polling_configuration. If a field in that set is populated, all other fields in the set will automatically be cleared.
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 272 class ClientConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] polling_interval # @return [::Google::Protobuf::Duration] # A duration describing the time between GetClientConfiguration RPCs. # Only strictly positive values are permissible. # @!attribute [rw] validity_duration # @return [::Google::Protobuf::Duration] # How long the client should consider the configuration it receives from # GetClientConfiguration valid for. Once this duration has passed, the # client should consider the configuration invalid and must either: # - Get a new configuration from GetClientConfiguration # - Or if it cannot, use a sane default configuration # # This duration will be at least as long as the polling interval. # @!attribute [rw] max_rpc_retry_count # @return [::Integer] # Number of times the client should retry a failed # GetClientConfiguration RPC per polling interval before giving up. class PollingConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#session_configuration ⇒ ::Google::Cloud::Bigtable::V2::SessionClientConfiguration
Returns The configuration for Bigtable Sessions.
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 272 class ClientConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] polling_interval # @return [::Google::Protobuf::Duration] # A duration describing the time between GetClientConfiguration RPCs. # Only strictly positive values are permissible. # @!attribute [rw] validity_duration # @return [::Google::Protobuf::Duration] # How long the client should consider the configuration it receives from # GetClientConfiguration valid for. Once this duration has passed, the # client should consider the configuration invalid and must either: # - Get a new configuration from GetClientConfiguration # - Or if it cannot, use a sane default configuration # # This duration will be at least as long as the polling interval. # @!attribute [rw] max_rpc_retry_count # @return [::Integer] # Number of times the client should retry a failed # GetClientConfiguration RPC per polling interval before giving up. class PollingConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#stop_polling ⇒ ::Boolean
Returns If the client should cease to check for new configurations, e.g. a backstop to prevent excessive GetClientConfiguration RPCs.
Note: The following fields are mutually exclusive: stop_polling, polling_interval, polling_configuration. If a field in that set is populated, all other fields in the set will automatically be cleared.
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 272 class ClientConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] polling_interval # @return [::Google::Protobuf::Duration] # A duration describing the time between GetClientConfiguration RPCs. # Only strictly positive values are permissible. # @!attribute [rw] validity_duration # @return [::Google::Protobuf::Duration] # How long the client should consider the configuration it receives from # GetClientConfiguration valid for. Once this duration has passed, the # client should consider the configuration invalid and must either: # - Get a new configuration from GetClientConfiguration # - Or if it cannot, use a sane default configuration # # This duration will be at least as long as the polling interval. # @!attribute [rw] max_rpc_retry_count # @return [::Integer] # Number of times the client should retry a failed # GetClientConfiguration RPC per polling interval before giving up. class PollingConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#telemetry_configuration ⇒ ::Google::Cloud::Bigtable::V2::TelemetryConfiguration
Returns Configuration for telemetry.
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 272 class ClientConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] polling_interval # @return [::Google::Protobuf::Duration] # A duration describing the time between GetClientConfiguration RPCs. # Only strictly positive values are permissible. # @!attribute [rw] validity_duration # @return [::Google::Protobuf::Duration] # How long the client should consider the configuration it receives from # GetClientConfiguration valid for. Once this duration has passed, the # client should consider the configuration invalid and must either: # - Get a new configuration from GetClientConfiguration # - Or if it cannot, use a sane default configuration # # This duration will be at least as long as the polling interval. # @!attribute [rw] max_rpc_retry_count # @return [::Integer] # Number of times the client should retry a failed # GetClientConfiguration RPC per polling interval before giving up. class PollingConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |