Class: Google::Cloud::Bigtable::V2::ClientConfiguration::PollingConfiguration
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::ClientConfiguration::PollingConfiguration
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/session.rb
Instance Attribute Summary collapse
-
#max_rpc_retry_count ⇒ ::Integer
Number of times the client should retry a failed GetClientConfiguration RPC per polling interval before giving up.
-
#polling_interval ⇒ ::Google::Protobuf::Duration
A duration describing the time between GetClientConfiguration RPCs.
-
#validity_duration ⇒ ::Google::Protobuf::Duration
How long the client should consider the configuration it receives from GetClientConfiguration valid for.
Instance Attribute Details
#max_rpc_retry_count ⇒ ::Integer
Returns Number of times the client should retry a failed GetClientConfiguration RPC per polling interval before giving up.
293 294 295 296 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 293 class PollingConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#polling_interval ⇒ ::Google::Protobuf::Duration
Returns A duration describing the time between GetClientConfiguration RPCs. Only strictly positive values are permissible.
293 294 295 296 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 293 class PollingConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#validity_duration ⇒ ::Google::Protobuf::Duration
Returns How long the client should consider the configuration it receives from GetClientConfiguration valid for. Once this duration has passed, the client should consider the configuration invalid and must either:
- Get a new configuration from GetClientConfiguration
- Or if it cannot, use a sane default configuration
This duration will be at least as long as the polling interval.
293 294 295 296 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 293 class PollingConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |