Class: Google::Cloud::Bigtable::V2::CloseSessionRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::CloseSessionRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/session.rb
Overview
Internal usage only.
Defined Under Namespace
Modules: CloseSessionReason
Instance Attribute Summary collapse
- #description ⇒ ::String
- #reason ⇒ ::Google::Cloud::Bigtable::V2::CloseSessionRequest::CloseSessionReason
Instance Attribute Details
#description ⇒ ::String
409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 409 class CloseSessionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Client-generated reason for terminating the session, including a # plain-text description of why. # 'reason' may be used for metrics, while both may be logged (server-side). module CloseSessionReason CLOSE_SESSION_REASON_UNSET = 0 CLOSE_SESSION_REASON_GOAWAY = 1 CLOSE_SESSION_REASON_ERROR = 2 CLOSE_SESSION_REASON_USER = 3 CLOSE_SESSION_REASON_DOWNSIZE = 4 CLOSE_SESSION_REASON_MISSED_HEARTBEAT = 5 end end |
#reason ⇒ ::Google::Cloud::Bigtable::V2::CloseSessionRequest::CloseSessionReason
409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 409 class CloseSessionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Client-generated reason for terminating the session, including a # plain-text description of why. # 'reason' may be used for metrics, while both may be logged (server-side). module CloseSessionReason CLOSE_SESSION_REASON_UNSET = 0 CLOSE_SESSION_REASON_GOAWAY = 1 CLOSE_SESSION_REASON_ERROR = 2 CLOSE_SESSION_REASON_USER = 3 CLOSE_SESSION_REASON_DOWNSIZE = 4 CLOSE_SESSION_REASON_MISSED_HEARTBEAT = 5 end end |