Class: Google::Cloud::Bigtable::V2::ExecuteQueryRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::ExecuteQueryRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/bigtable.rb
Overview
Request message for Bigtable.ExecuteQuery
Defined Under Namespace
Classes: ParamsEntry
Instance Attribute Summary collapse
-
#app_profile_id ⇒ ::String
Optional.
-
#instance_name ⇒ ::String
Required.
-
#params ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Bigtable::V2::Value}
Required.
-
#proto_format ⇒ ::Google::Cloud::Bigtable::V2::ProtoFormat
Protocol buffer format as described by ProtoSchema and ProtoRows messages.
-
#query ⇒ ::String
Required.
-
#resume_token ⇒ ::String
Optional.
Instance Attribute Details
#app_profile_id ⇒ ::String
Returns Optional. This value specifies routing for replication. If not specified,
the default application profile will be used.
811 812 813 814 815 816 817 818 819 820 821 822 823 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 811 class ExecuteQueryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Bigtable::V2::Value] class ParamsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#instance_name ⇒ ::String
Returns Required. The unique name of the instance against which the query should be
executed.
Values are of the form projects/<project>/instances/<instance>.
811 812 813 814 815 816 817 818 819 820 821 822 823 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 811 class ExecuteQueryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Bigtable::V2::Value] class ParamsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#params ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Bigtable::V2::Value}
Returns Required. params contains string type keys and Bigtable type values that
bind to placeholders in the query string. In query string, a parameter
placeholder consists of the
@ character followed by the parameter name (for example, @firstName) in
the query string.
For example, if
params["firstName"] = bytes_value: "foo" type {bytes_type {}}
then @firstName will be replaced with googlesql bytes value "foo" in the
query string during query evaluation.
In case of Value.kind is not set, it will be set to corresponding null
value in googlesql.
params["firstName"] = type {string_type {}}
then @firstName will be replaced with googlesql null string.
Value.type should always be set and no inference of type will be made from Value.kind. If Value.type is not set, we will return INVALID_ARGUMENT error.
811 812 813 814 815 816 817 818 819 820 821 822 823 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 811 class ExecuteQueryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Bigtable::V2::Value] class ParamsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#proto_format ⇒ ::Google::Cloud::Bigtable::V2::ProtoFormat
Returns Protocol buffer format as described by ProtoSchema and ProtoRows messages.
811 812 813 814 815 816 817 818 819 820 821 822 823 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 811 class ExecuteQueryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Bigtable::V2::Value] class ParamsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#query ⇒ ::String
Returns Required. The query string.
811 812 813 814 815 816 817 818 819 820 821 822 823 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 811 class ExecuteQueryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Bigtable::V2::Value] class ParamsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#resume_token ⇒ ::String
Returns Optional. If this request is resuming a previously interrupted query
execution, resume_token should be copied from the last
PartialResultSet yielded before the interruption. Doing this
enables the query execution to resume where the last one left
off.
The rest of the request parameters must exactly match the
request that yielded this token. Otherwise the request will fail.
811 812 813 814 815 816 817 818 819 820 821 822 823 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 811 class ExecuteQueryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Bigtable::V2::Value] class ParamsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |