Class: Google::Cloud::Bigtable::V2::FeatureFlags

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/bigtable/v2/feature_flags.rb

Overview

Feature flags supported by a client. This is intended to be sent as part of request metadata to assure the server that certain behaviors are safe to enable. This proto is meant to be serialized and websafe-base64 encoded under the bigtable-features metadata key. The value will remain constant for the lifetime of a client and due to HTTP2's HPACK compression, the request overhead will be tiny. This is an internal implementation detail and should not be used by endusers directly.

Instance Attribute Summary collapse

Instance Attribute Details

#last_scanned_row_responses::Boolean

Returns Notify the server that the client supports the last_scanned_row field in ReadRowsResponse for long-running sparse scans.

Returns:

  • (::Boolean)

    Notify the server that the client supports the last_scanned_row field in ReadRowsResponse for long-running sparse scans.



44
45
46
47
# File 'proto_docs/google/bigtable/v2/feature_flags.rb', line 44

class FeatureFlags
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#mutate_rows_rate_limit::Boolean

Returns Notify the server that the client enables batch write flow control by requesting RateLimitInfo from MutateRowsResponse.

Returns:

  • (::Boolean)

    Notify the server that the client enables batch write flow control by requesting RateLimitInfo from MutateRowsResponse.



44
45
46
47
# File 'proto_docs/google/bigtable/v2/feature_flags.rb', line 44

class FeatureFlags
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#reverse_scans::Boolean

Returns Notify the server that the client supports reverse scans. The server will reject ReadRowsRequests with the reverse bit set when this is absent.

Returns:

  • (::Boolean)

    Notify the server that the client supports reverse scans. The server will reject ReadRowsRequests with the reverse bit set when this is absent.



44
45
46
47
# File 'proto_docs/google/bigtable/v2/feature_flags.rb', line 44

class FeatureFlags
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end