Class: Google::Cloud::Bigtable::V2::FeatureFlags
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::FeatureFlags
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/feature_flags.rb
Overview
Feature flags supported by a client.
This is intended to be sent as part of request metadata to assure the server
that certain behaviors are safe to enable. This proto is meant to be
serialized and websafe-base64 encoded under the bigtable-features metadata
key. The value will remain constant for the lifetime of a client and due to
HTTP2's HPACK compression, the request overhead will be tiny.
This is an internal implementation detail and should not be used by endusers
directly.
Instance Attribute Summary collapse
-
#mutate_rows_rate_limit ⇒ ::Boolean
Notify the server that the client enables batch write flow control by requesting RateLimitInfo from MutateRowsResponse.
Instance Attribute Details
#mutate_rows_rate_limit ⇒ ::Boolean
Returns Notify the server that the client enables batch write flow control by requesting RateLimitInfo from MutateRowsResponse.
36 37 38 39 |
# File 'proto_docs/google/bigtable/v2/feature_flags.rb', line 36 class FeatureFlags include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |