Class: Google::Cloud::Bigtable::V2::GoAwayResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::GoAwayResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/session.rb
Overview
Internal usage only.
Instance Attribute Summary collapse
- #description ⇒ ::String
-
#last_rpc_id_admitted ⇒ ::Integer
The last vRPC which was admitted by the AFE.
-
#reason ⇒ ::String
Server-generated reason for GOAWAY, including a plain-text description of why.
Instance Attribute Details
#description ⇒ ::String
745 746 747 748 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 745 class GoAwayResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#last_rpc_id_admitted ⇒ ::Integer
Returns The last vRPC which was admitted by the AFE. The client may expect the result from the vRPC on the stream before disconnecting, and should retry vRPCs beyond this boundary.
745 746 747 748 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 745 class GoAwayResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#reason ⇒ ::String
Returns Server-generated reason for GOAWAY, including a plain-text description of why. 'reason' may be used for CSM, while both may be logged.
745 746 747 748 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 745 class GoAwayResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |