Class: Google::Cloud::Bigtable::V2::LoadBalancingOptions::LeastInFlight
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::LoadBalancingOptions::LeastInFlight
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/session.rb
Overview
Balances vRPCs over backends, preferring to send new vRPCs to AFEs with the least number of active vRPCs.
Instance Attribute Summary collapse
-
#random_subset_size ⇒ ::Integer
Of all connected AFEs, the size of the random subset to run the algorithm on.
Instance Attribute Details
#random_subset_size ⇒ ::Integer
Returns Of all connected AFEs, the size of the random subset to run the algorithm on. Zero implies all connected AFEs.
62 63 64 65 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 62 class LeastInFlight include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |