Class: Google::Cloud::Bigtable::V2::MutateRowsRequest::Entry
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::MutateRowsRequest::Entry
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/bigtable.rb
Overview
A mutation for a given row.
Instance Attribute Summary collapse
-
#mutations ⇒ ::Array<::Google::Cloud::Bigtable::V2::Mutation>
Required.
-
#row_key ⇒ ::String
The key of the row to which the
mutationsshould be applied.
Instance Attribute Details
#mutations ⇒ ::Array<::Google::Cloud::Bigtable::V2::Mutation>
Returns Required. Changes to be atomically applied to the specified row. Mutations are applied in order, meaning that earlier mutations can be masked by later ones. You must specify at least one mutation.
226 227 228 229 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 226 class Entry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |