Class: Google::Cloud::Bigtable::V2::MutateRowsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::MutateRowsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/bigtable.rb
Overview
Response message for BigtableService.MutateRows.
Defined Under Namespace
Classes: Entry
Instance Attribute Summary collapse
-
#entries ⇒ ::Array<::Google::Cloud::Bigtable::V2::MutateRowsResponse::Entry>
One or more results for Entries from the batch request.
Instance Attribute Details
#entries ⇒ ::Array<::Google::Cloud::Bigtable::V2::MutateRowsResponse::Entry>
Returns One or more results for Entries from the batch request.
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 280 class MutateRowsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of applying a passed mutation in the original request. # @!attribute [rw] index # @return [::Integer] # The index into the original request's `entries` list of the Entry # for which a result is being reported. # @!attribute [rw] status # @return [::Google::Rpc::Status] # The result of the request Entry identified by `index`. # Depending on how requests are batched during execution, it is possible # for one Entry to fail due to an error with another Entry. In the event # that this occurs, the same error will be reported for both entries. class Entry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |