Class: Google::Cloud::Bigtable::V2::OpenAuthorizedViewRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::OpenAuthorizedViewRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/session.rb
Overview
Open sessions for an AuthorizedView. Internal usage only.
Defined Under Namespace
Modules: Permission
Instance Attribute Summary collapse
-
#app_profile_id ⇒ ::String
The app profile id to use for the authorized view sessions.
-
#authorized_view_name ⇒ ::String
The Authorized view name to read and write from.
-
#permission ⇒ ::Google::Cloud::Bigtable::V2::OpenAuthorizedViewRequest::Permission
Permission for the session.
Instance Attribute Details
#app_profile_id ⇒ ::String
Returns The app profile id to use for the authorized view sessions.
470 471 472 473 474 475 476 477 478 479 480 481 482 483 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 470 class OpenAuthorizedViewRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module Permission PERMISSION_UNSET = 0 PERMISSION_READ = 1 PERMISSION_WRITE = 2 PERMISSION_READ_WRITE = 3 end end |
#authorized_view_name ⇒ ::String
Returns The Authorized view name to read and write from. Values are of the form
projects/<project>/instances/<instance>/tables/<table>/authorizedViews/<authorized_view>.
470 471 472 473 474 475 476 477 478 479 480 481 482 483 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 470 class OpenAuthorizedViewRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module Permission PERMISSION_UNSET = 0 PERMISSION_READ = 1 PERMISSION_WRITE = 2 PERMISSION_READ_WRITE = 3 end end |
#permission ⇒ ::Google::Cloud::Bigtable::V2::OpenAuthorizedViewRequest::Permission
Returns Permission for the session.
470 471 472 473 474 475 476 477 478 479 480 481 482 483 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 470 class OpenAuthorizedViewRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module Permission PERMISSION_UNSET = 0 PERMISSION_READ = 1 PERMISSION_WRITE = 2 PERMISSION_READ_WRITE = 3 end end |