Class: Google::Cloud::Bigtable::V2::OpenSessionRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::OpenSessionRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/session.rb
Overview
Internal usage only.
Instance Attribute Summary collapse
-
#consecutive_failed_connection_attempts ⇒ ::Integer
Used for serverside observability.
-
#flags ⇒ ::Google::Cloud::Bigtable::V2::FeatureFlags
Client settings, including a record of.
-
#payload ⇒ ::String
Can be Open{Table,AuthorizedView,MaterializedView}Request, (or in post-V1, PrepareSqlQueryRequest).
-
#protocol_version ⇒ ::Integer
A version indicator from the client stating its understanding of the protocol.
-
#routing_cookie ⇒ ::String
How the request should be routed (if presented as part of a GOAWAY from a previous session).
Instance Attribute Details
#consecutive_failed_connection_attempts ⇒ ::Integer
Returns Used for serverside observability.
366 367 368 369 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 366 class OpenSessionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#flags ⇒ ::Google::Cloud::Bigtable::V2::FeatureFlags
Returns Client settings, including a record of.
366 367 368 369 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 366 class OpenSessionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#payload ⇒ ::String
Returns Can be Open{Table,AuthorizedView,MaterializedView}Request, (or in post-V1, PrepareSqlQueryRequest).
366 367 368 369 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 366 class OpenSessionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#protocol_version ⇒ ::Integer
Returns A version indicator from the client stating its understanding of the protocol. This is to disambiguate client behavior amidst changes in semantic usage of the API, e.g. if the structure remains the same but behavior changes.
366 367 368 369 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 366 class OpenSessionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#routing_cookie ⇒ ::String
Returns How the request should be routed (if presented as part of a GOAWAY from a previous session). Post V1.
366 367 368 369 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 366 class OpenSessionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |