Class: Google::Cloud::Bigtable::V2::ReadRowsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/bigtable/v2/bigtable.rb

Overview

Request message for Bigtable.ReadRows.

Instance Attribute Summary collapse

Instance Attribute Details

#app_profile_id::String

Returns This value specifies routing for replication. If not specified, the "default" application profile will be used.

Returns:

  • (::String)

    This value specifies routing for replication. If not specified, the "default" application profile will be used.



46
47
48
49
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 46

class ReadRowsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#filter::Google::Cloud::Bigtable::V2::RowFilter

Returns The filter to apply to the contents of the specified row(s). If unset, reads the entirety of each row.

Returns:



46
47
48
49
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 46

class ReadRowsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rows::Google::Cloud::Bigtable::V2::RowSet

Returns The row keys and/or ranges to read sequentially. If not specified, reads from all rows.

Returns:



46
47
48
49
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 46

class ReadRowsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rows_limit::Integer

Returns The read will stop after committing to N rows' worth of results. The default (zero) is to return all results.

Returns:

  • (::Integer)

    The read will stop after committing to N rows' worth of results. The default (zero) is to return all results.



46
47
48
49
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 46

class ReadRowsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#table_name::String

Returns Required. The unique name of the table from which to read. Values are of the form projects/<project>/instances/<instance>/tables/<table>.

Returns:

  • (::String)

    Required. The unique name of the table from which to read. Values are of the form projects/<project>/instances/<instance>/tables/<table>.



46
47
48
49
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 46

class ReadRowsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end