Class: Google::Cloud::Bigtable::V2::SampleRowKeysRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::SampleRowKeysRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/bigtable.rb
Overview
Request message for Bigtable.SampleRowKeys.
Instance Attribute Summary collapse
-
#app_profile_id ⇒ ::String
This value specifies routing for replication.
-
#authorized_view_name ⇒ ::String
Optional.
-
#materialized_view_name ⇒ ::String
Optional.
-
#row_range ⇒ ::Google::Cloud::Bigtable::V2::RowRange
Optional.
-
#table_name ⇒ ::String
Optional.
Instance Attribute Details
#app_profile_id ⇒ ::String
Returns This value specifies routing for replication. If not specified, the "default" application profile will be used.
220 221 222 223 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 220 class SampleRowKeysRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#authorized_view_name ⇒ ::String
Returns Optional. The unique name of the AuthorizedView from which to sample row keys.
Values are of the form
projects/<project>/instances/<instance>/tables/<table>/authorizedViews/<authorized_view>.
220 221 222 223 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 220 class SampleRowKeysRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#materialized_view_name ⇒ ::String
Returns Optional. The unique name of the MaterializedView from which to read.
Values are of the form
projects/<project>/instances/<instance>/materializedViews/<materialized_view>.
220 221 222 223 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 220 class SampleRowKeysRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#row_range ⇒ ::Google::Cloud::Bigtable::V2::RowRange
Optional. The row range to sample. If not specified, samples from all rows. The output will always return the end key in the range as the last sample returned.
220 221 222 223 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 220 class SampleRowKeysRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#table_name ⇒ ::String
Returns Optional. The unique name of the table from which to sample row keys.
Values are of the form
projects/<project>/instances/<instance>/tables/<table>.
220 221 222 223 |
# File 'proto_docs/google/bigtable/v2/bigtable.rb', line 220 class SampleRowKeysRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |