Class: Google::Cloud::Bigtable::V2::SessionRefreshConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::SessionRefreshConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/session.rb
Overview
Internal usage only.
Defined Under Namespace
Classes: Metadata
Instance Attribute Summary collapse
-
#metadata ⇒ ::Array<::Google::Cloud::Bigtable::V2::SessionRefreshConfig::Metadata>
readonly
Output only.
-
#optimized_open_request ⇒ ::Google::Cloud::Bigtable::V2::OpenSessionRequest
An optimized Open request that the session may use on a retry when establishing this session again.
Instance Attribute Details
#metadata ⇒ ::Array<::Google::Cloud::Bigtable::V2::SessionRefreshConfig::Metadata> (readonly)
Returns Output only. Any additional metadata to include when reconnecting.
759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 759 class SessionRefreshConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Any additional metadata to include when reconnecting. Not a `map<>` type as # this can be a multimap. # @!attribute [r] key # @return [::String] # Output only. The key for the metadata entry. # @!attribute [r] value # @return [::String] # Output only. The value for the metadata entry. class Metadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#optimized_open_request ⇒ ::Google::Cloud::Bigtable::V2::OpenSessionRequest
Returns An optimized Open request that the session may use on a retry when establishing this session again. This can be sent from the AFE to avoid certain work e.g. encoding a query plan for BTQL.
759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 759 class SessionRefreshConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Any additional metadata to include when reconnecting. Not a `map<>` type as # this can be a multimap. # @!attribute [r] key # @return [::String] # Output only. The key for the metadata entry. # @!attribute [r] value # @return [::String] # Output only. The value for the metadata entry. class Metadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |