Class: Google::Cloud::Bigtable::V2::SessionResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::SessionResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/session.rb
Overview
Internal usage only.
Instance Attribute Summary collapse
-
#error ⇒ ::Google::Cloud::Bigtable::V2::ErrorResponse
Note: The following fields are mutually exclusive:
error,open_session,virtual_rpc,session_parameters,heartbeat,go_away,session_refresh_config. -
#go_away ⇒ ::Google::Cloud::Bigtable::V2::GoAwayResponse
Note: The following fields are mutually exclusive:
go_away,open_session,virtual_rpc,error,session_parameters,heartbeat,session_refresh_config. -
#heartbeat ⇒ ::Google::Cloud::Bigtable::V2::HeartbeatResponse
Note: The following fields are mutually exclusive:
heartbeat,open_session,virtual_rpc,error,session_parameters,go_away,session_refresh_config. -
#open_session ⇒ ::Google::Cloud::Bigtable::V2::OpenSessionResponse
Note: The following fields are mutually exclusive:
open_session,virtual_rpc,error,session_parameters,heartbeat,go_away,session_refresh_config. -
#session_parameters ⇒ ::Google::Cloud::Bigtable::V2::SessionParametersResponse
Note: The following fields are mutually exclusive:
session_parameters,open_session,virtual_rpc,error,heartbeat,go_away,session_refresh_config. -
#session_refresh_config ⇒ ::Google::Cloud::Bigtable::V2::SessionRefreshConfig
Note: The following fields are mutually exclusive:
session_refresh_config,open_session,virtual_rpc,error,session_parameters,heartbeat,go_away. -
#virtual_rpc ⇒ ::Google::Cloud::Bigtable::V2::VirtualRpcResponse
A vRPC can result in either a successful result or an error.
Instance Attribute Details
#error ⇒ ::Google::Cloud::Bigtable::V2::ErrorResponse
Returns Note: The following fields are mutually exclusive: error, open_session, virtual_rpc, session_parameters, heartbeat, go_away, session_refresh_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
340 341 342 343 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 340 class SessionResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#go_away ⇒ ::Google::Cloud::Bigtable::V2::GoAwayResponse
Returns Note: The following fields are mutually exclusive: go_away, open_session, virtual_rpc, error, session_parameters, heartbeat, session_refresh_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
340 341 342 343 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 340 class SessionResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#heartbeat ⇒ ::Google::Cloud::Bigtable::V2::HeartbeatResponse
Returns Note: The following fields are mutually exclusive: heartbeat, open_session, virtual_rpc, error, session_parameters, go_away, session_refresh_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
340 341 342 343 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 340 class SessionResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#open_session ⇒ ::Google::Cloud::Bigtable::V2::OpenSessionResponse
Returns Note: The following fields are mutually exclusive: open_session, virtual_rpc, error, session_parameters, heartbeat, go_away, session_refresh_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
340 341 342 343 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 340 class SessionResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#session_parameters ⇒ ::Google::Cloud::Bigtable::V2::SessionParametersResponse
Returns Note: The following fields are mutually exclusive: session_parameters, open_session, virtual_rpc, error, heartbeat, go_away, session_refresh_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
340 341 342 343 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 340 class SessionResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#session_refresh_config ⇒ ::Google::Cloud::Bigtable::V2::SessionRefreshConfig
Returns Note: The following fields are mutually exclusive: session_refresh_config, open_session, virtual_rpc, error, session_parameters, heartbeat, go_away. If a field in that set is populated, all other fields in the set will automatically be cleared.
340 341 342 343 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 340 class SessionResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#virtual_rpc ⇒ ::Google::Cloud::Bigtable::V2::VirtualRpcResponse
Returns A vRPC can result in either a successful result or an error. Error results are separate to allow for multiple vRPC responses, e.g. for streaming calls like scans (post-V1). See Flow Control.
Note: The following fields are mutually exclusive: virtual_rpc, open_session, error, session_parameters, heartbeat, go_away, session_refresh_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
340 341 342 343 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 340 class SessionResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |