Class: Google::Cloud::Bigtable::V2::TelemetryConfiguration
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::TelemetryConfiguration
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/session.rb
Overview
Server provided instructions for enabling finer grained observability on the client to help diagnose customer issues. Internal usage only.
Defined Under Namespace
Modules: Level
Instance Attribute Summary collapse
-
#debug_tag_level ⇒ ::Google::Cloud::Bigtable::V2::TelemetryConfiguration::Level
Selector for the debug counters that should be uploaded.
Instance Attribute Details
#debug_tag_level ⇒ ::Google::Cloud::Bigtable::V2::TelemetryConfiguration::Level
Returns Selector for the debug counters that should be uploaded.
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 222 class TelemetryConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The level of detail of telemetry to be sent from the client. module Level # Server did not specify a level. Should disable all debug tag counters. LEVEL_UNSPECIFIED = 0 # Enables all debug tag counter levels. DEBUG = 1 # Eables all debug tag counters except for DEBUG. INFO = 2 # Enables all debug tag counters except for DEBUG and INFO. WARN = 3 # Enables only error debug tag counters. ERROR = 4 end end |