Class: Google::Cloud::Bigtable::V2::VirtualRpcRequest::Metadata
- Inherits:
-
Object
- Object
- Google::Cloud::Bigtable::V2::VirtualRpcRequest::Metadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/bigtable/v2/session.rb
Overview
Container for all vRPC Metadata.
Instance Attribute Summary collapse
-
#attempt_number ⇒ ::Integer
Track retry attempts for this vRPC at the AFE.
-
#attempt_start ⇒ ::Google::Protobuf::Timestamp
Track the client's known start time for the attempt.
-
#traceparent ⇒ ::String
Link OpenTelemetry traces (e.g. Tapper).
Instance Attribute Details
#attempt_number ⇒ ::Integer
Returns Track retry attempts for this vRPC at the AFE.
554 555 556 557 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 554 class Metadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#attempt_start ⇒ ::Google::Protobuf::Timestamp
Returns Track the client's known start time for the attempt. This is likely not easily compared with the server's time due to clock skew.
554 555 556 557 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 554 class Metadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#traceparent ⇒ ::String
Returns Link OpenTelemetry traces (e.g. Tapper). This can be used to link attempts together for the same logical operation (e.g. in logs / traces).
Note, this may not be needed for V1, TBD.
554 555 556 557 |
# File 'proto_docs/google/bigtable/v2/session.rb', line 554 class Metadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |